"""Provides all the data related to the games."""

GAMING_PLATFORMS = [
    'Nintendo 64',
    'Nintendo Switch',
    'PC',
    'PlayStation 3',
    'PlayStation 4',
    'PlayStation 4 Pro',
    'PlayStation Vita',
    'Xbox 360',
    'Xbox One',
    'Xbox One S',
    'Xbox One X',
]

SCORE_PHRASES = [
    'Amazing',
    'Awful',
    'Bad',
    'Disaster',
    'Good',
    'Great',
    'Masterpiece',
    'Mediocre',
    'Okay',
    'Painful',
    'Unbearable',
]

GENRES = [
    'Action',
    'Action, Adventure',
    'Action, Compilation',
    'Action, Platformer',
    'Action, Puzzle',
    'Action, RPG',
    'Action, Simulation',
    'Action, Strategy',
    'Adventure',
    'Adventure, Adult',
    'Adventure, Adventure',
    'Adventure, Compilation',
    'Adventure, Episodic',
    'Adventure, Platformer',
    'Adventure, RPG',
    'Baseball',
    'Battle',
    'Board',
    'Card',
    'Card, Battle',
    'Compilation',
    'Compilation, RPG',
    'Educational',
    'Educational, Adventure',
    'Educational, Puzzle',
    'Fighting',
    'Fighting, Action',
    'Fighting, Compilation',
    'Fighting, Simulation',
    'Flight',
    'Flight, Action',
    'Flight, Simulation',
    'Hardware',
    'Hunting',
    'Music',
    'Music, Action',
    'Music, Adventure',
    'Music, RPG',
    'Other',
    'Other, Adventure',
    'Party',
    'Pinball',
    'Platformer',
    'Platformer, Action',
    'Platformer, Adventure',
    'Productivity',
    'Productivity, Action',
    'Puzzle',
    'Puzzle, Action',
    'Puzzle, Adventure',
    'Puzzle, Compilation',
    'Puzzle, Platformer',
    'Puzzle, RPG',
    'Puzzle, Word Game',
    'RPG',
    'RPG, Action',
    'RPG, Simulation',
    'Racing',
    'Racing, Action',
    'Shooter',
    'Shooter, Adventure',
    'Shooter, First-Person',
    'Shooter, RPG',
    'Simulation',
    'Simulation, Adventure',
    'Sports',
    'Sports, Action',
    'Sports, Baseball',
    'Sports, Compilation',
    'Sports, Fighting',
    'Sports, Golf',
    'Sports, Other',
    'Sports, Party',
    'Sports, Simulation',
    'Strategy',
    'Strategy, RPG',
    'Strategy, Simulation',
    'Trivia',
    'Virtual Pet',
    'Wrestling',
]

GAMES = [
    '007 Legends',
    '1-bit Ninja',
    '2Bit',
    '3 Heroes -- Crystal Soul',
    '3D Classics: Excitebike',
    "3D Classics: Kirby's Adventure",
    '3D Classics: TwinBee',
    '3D Classics: Urban Champion',
    '3D Classics: Xevious',
    '3D Pixel Racing',
    '4 Elements HD',
    '4 Elements II',
    '7 Days to Die',
    '80 Days',
    '99Bullets',
    '101-in-1 Explosive Megamix',
    '140',
    '1001 BlockBusters',
    '1001 Spikes',
    '1942 (Arcade)',
    "1950's Lawnmower Kids",
    '1979 Revolution',
    '2014 FIFA World Cup Brazil',
    '10000000',
    'Infinity Field HD',
    'Infinity Field',
    'Infinity Blade III',
    'Infinity Blade II',
    '#IDARB',
    'A Bird Story',
    'A Game of Thrones: Genesis',
    'A Valley Without Wind',
    'A Virus Named Tom',
    'A.R.E.S.: Extinction Agenda',
    'AFL Live',
    'ARC Squadron',
    "Aaru's Awakening",
    'Abyss Odyssey',
    'Abzu',
    'Academy: Checkers',
    'Ace Combat Assault Horizon',
    'Ace Combat Assault Horizon Legacy',
    'Ace of Spades',
    'Achron',
    'Adr1ft',
    'Adr1ft [VR Edition]',
    'Adventure Island',
    "Adventure Time: Explore the Dungeon Because I Don't Know!",
    "Adventure Time: Hey Ice King! Why'd You Steal Our Garbage?",
    'AfterZoom',
    'Afterfall: Insanity',
    'Age of Empires Online',
    'Age of Wonders III',
    'Age of Wushu',
    'Air Conflicts: Secret Wars',
    'Air Conflicts: Vietnam',
    'Air Penguin',
    'AirBuccaneers',
    'AirMech Arena',
    'Akai Katana',
    'Akaneiro: Demon Hunters',
    'Akimi Village',
    'Alan Wake',
    "Alan Wake's American Nightmare",
    "Alekhine's Gun",
    'Alice: Madness Returns',
    'Alien Breed 3: Descent',
    'Alien Rage',
    'Alien Zombie Megadeath',
    'Alien: Isolation',
    'Aliens: Colonial Marines',
    'Aliens: Infestation',
    'All Zombies Must Die',
    'Alleyway',
    'Amnesia: A Machine for Pigs',
    'Among the Sleep',
    'Amplitude',
    'Amy',
    'Analogue: A Hate Story',
    'Anarchy Reigns',
    'Ancient Space',
    'Angry Birds',
    'Angry Birds 2',
    'Angry Birds Go!',
    'Angry Birds Rio',
    'Angry Birds Space',
    'Angry Birds Star Wars',
    'Angry Birds Trilogy',
    'Angry Business Man',
    'Anima: Ark of Sinners',
    'Animal Crossing: Amiibo Festival',
    'Animal Crossing: Happy Home Designer',
    'Animal Crossing: New Leaf',
    'Anna',
    'Anno 2070',
    'Anno 2205',
    'Anomaly 2',
    'Anomaly: Warzone Earth',
    'Another World',
    'Another World: 20th Anniversary Edition',
    'Anthill: Tactical Trail Defense',
    'Antichamber',
    'Apotheon',
    'Apox',
    'Apple Jack 2',
    'AquaPazza',
    'Ar tonelico Qoga: Knell of Ar Ciel',
    'Arcade Essentials',
    'ArmA III',
    'Armello',
    'Armored Core V',
    'Armored Core: Verdict Day',
    'Army Corps of Hell',
    'Army of Darkness: Defense',
    "Army of Two: The Devil's Cartel",
    'Art Academy: Lessons for Everyone',
    'Ash',
    'Ashes of Singularity',
    'Asphalt 3D',
    'Asphalt 7: Heat',
    'Asphalt Injection',
    "Assassin's Creed Brotherhood: The Da Vinci Disappearence",
    "Assassin's Creed Chronicles: China",
    "Assassin's Creed Chronicles: India",
    "Assassin's Creed Chronicles: Russia",
    "Assassin's Creed III",
    "Assassin's Creed III -- The Tyranny of King Washington",
    "Assassin's Creed III: Liberation",
    "Assassin's Creed IV: Black Flag",
    "Assassin's Creed IV: Black Flag -- Freedom Cry",
    "Assassin's Creed Liberation HD",
    "Assassin's Creed Pirates",
    "Assassin's Creed Recollection",
    "Assassin's Creed Syndicate",
    "Assassin's Creed Unity",
    "Assassin's Creed Unity -- Dead Kings",
    "Assassin's Creed: Brotherhood",
    "Assassin's Creed: Revelations",
    'Assassin’s Creed Rogue',
    'Assault Android Cactus',
    'Assetto Corsa',
    "Asura's Wrath",
    'Atelier Ayesha: The Alchemist of Dusk',
    'Atelier Escha & Logy: Alchemist of Dusk Sky',
    'Atelier Meruru: The Apprentice of Arland',
    'Atelier Totori Plus: The Adventurer of Arland',
    'Atelier Totori: The Adventurer of Arland',
    'Atom Zombie Smasher',
    'Attack of the Friday Monsters: A Tokyo Tale',
    'Attack on Titan',
    'Attack on Titan: Humanity in Chains',
    'Audiosurf 2',
    'Auditorium',
    'Avengers Initiative',
    'Avenging Spirit',
    'Awesomenauts',
    'Aww, Eggplant',
    'Axiom Verge',
    'Aya and the Cubes of Light',
    'Azure Striker: Gunvolt',
    'B Team - Episode 2: Ice & Venom',
    'Babel Rising',
    'Back to the Future: The Game',
    "Back to the Future: The Game -- Episode 1: It's About Time",
    'Back to the Future: The Game -- Episode 2: Get Tannen!',
    'Back to the Future: The Game -- Episode 3: Citizen Brown',
    'Back to the Future: The Game -- Episode 4: Double Visions',
    'Back to the Future: The Game -- Episode 5: Outatime',
    'BackStab',
    'Backbreaker Vengeance',
    'Bad Piggies',
    "Baldur's Gate -- Enhanced Edition",
    "Baldur's Gate II -- Enhanced Edition",
    'Balloon Kid',
    'Banana Kong',
    'BandFuse: Rock Legends',
    'Bangai-O HD: Missile Fury',
    'Banished',
    'Baseball',
    'Basement Crawl',
    'Bastion',
    'Batman: Arkham City',
    'Batman: Arkham City -- Armored Edition',
    "Batman: Arkham City -- Harley Quinn's Revenge",
    'Batman: Arkham City Lockdown',
    'Batman: Arkham Knight',
    'Batman: Arkham Knight -- Batgirl: A Matter of Family',
    "Batman: Arkham Knight -- Catwoman's Revenge",
    'Batman: Arkham Origins',
    'Batman: Arkham Origins -- Cold, Cold Heart',
    'Batman: Arkham Origins Blackgate',
    'Batman: Arkham Origins Blackgate -- Deluxe Edition',
    'Batman: The Telltale Series -- Episode 1: Realm of Shadows',
    'Batman: The Telltale Series -- Episode 2: Children of Arkham',
    'Battle Princess of Arcadias',
    'Battle of the Elements',
    'Battle: Los Angeles',
    'BattleBlock Theater',
    'Battleborn',
    'Battlefield 3',
    'Battlefield 4',
    'Battlefield Hardline',
    'Battlefield 1',
    'Battlefleet Gothic: Armada',
    'Battleheart',
    'Bayonetta 2',
    'Beat Hazard Ultra',
    'Beat Sneak Bandit',
    'Beatdown!',
    'Before the Echo',
    'Bejeweled 3',
    'Bejeweled Blitz Live',
    'Betrayer',
    'Beyond Eyes',
    'Beyond Good & Evil HD',
    'Beyond: Two Souls',
    "Bientot L'ete",
    'Big Bass Arcade',
    'Big Town Shoot Out',
    'Bike Baron',
    'Binary Domain',
    'BioShock',
    'BioShock Infinite',
    'BioShock: The Collection',
    'Bionic Commando',
    'Bionic Commando Rearmed 2',
    'Bioshock Infinite: Burial at Sea -- Episode One',
    'Bioshock Infinite: Burial at Sea -- Episode Two',
    'Bird Zapper!',
    'Bit.Trip Complete',
    'Bit.Trip Flux',
    'Bit.Trip Presents: Runner 2 Future Legend of Rhythm Alien',
    'Bit.Trip Runner',
    'Bit.Trip Saga',
    'Black Knight Sword',
    'Black Mirror III: Final Fear',
    'Black Prophecy',
    'Black Tiger',
    'Blackguards',
    'Blackguards 2',
    'Blacklight: Retribution',
    'Blackwater',
    'Bladeslinger: Episode 1',
    'Blaster Master: Enemy Below',
    'BlazBlue: Chrono Phantasma',
    'BlazBlue: Continuum Shift Extend',
    'BlazBlue: Continuum Shift II',
    'Bleach: Soul Resurreccion',
    'Blockado: Puzzle Island',
    'Blocks That Matter',
    'Blood Bowl II',
    'BloodRayne: Betrayal',
    'Bloodborne',
    'Bloodborne: The Old Hunters',
    'Bloodforge',
    'Bloodline Champions',
    'Bloons Tower Defense',
    'Blue Estate',
    'Boardwalk Ball Toss',
    'Bobby Carrot Forever',
    'Body and Brain Connection',
    'Bodycount',
    'Bomberman Hero',
    'Bombshell',
    'Boom Beach',
    'Borderlands 2',
    "Borderlands 2: Captain Scarlett and her Pirate's Booty",
    'Borderlands 2: How Marcus Saved Mercenary Day',
    'Borderlands 2: Mad Moxxi and the Wedding Day Massacre',
    "Borderlands 2: Mr. Torgue's Campaign of Carnage",
    "Borderlands 2: Sir Hammerlock's Big Game Hunt",
    "Borderlands 2: T.K. Baha's Bloody Harvest",
    "Borderlands 2: Tiny Tina's Assault on Dragon Keep",
    'Borderlands Legends',
    'Borderlands: The Handsome Collection',
    'Borderlands: The Pre-Sequel',
    'Borderlands: The Pre-Sequel -- Claptastic Voyage',
    'Botanicula',
    'Boulder Dash-XL',
    'Bound by Flame',
    'BoxBoxBoy!',
    'BoxBoy!',
    'Brain Age: Concentration Training',
    'Bravely Default',
    'Bravely Second: End Layer',
    'Brawl Brothers',
    'Breach',
    'Break Tactics',
    'Breakeroids',
    'Bridge',
    'Bring Me Sandwiches!!',
    'Brink',
    'Broforce',
    'Broken Age: Act 1',
    'Broken Age: Act 2',
    'Brothers: A Tale of Two Sons',
    "Bugs'N'Balls",
    'Build-A-Lot',
    'Bulletstorm',
    'Bumpy Road',
    'BurgerTime Deluxe',
    'BurgerTime World Tour',
    'Burn the City',
    'Burn the Rope',
    'Burnout Crash',
    'Bust-A-Move Universe',
    'Cafeteria Nipponica',
    'Cake Ninja',
    'Calculator',
    'Call of Duty: Advanced Warfare',
    'Call of Duty: Black Ops Declassified',
    'Call of Duty: Black Ops II',
    'Call of Duty: Black Ops III',
    'Call of Duty: Ghosts',
    'Call of Duty: Modern Warfare 3',
    'Call of Duty: Strike Team',
    'Call of Juarez: Gunslinger',
    'Call of Juarez: The Cartel',
    'Capsized',
    'Captain America: Super Soldier',
    'Captain Toad: Treasure Tracker',
    'Cardboard Castle',
    'Cargo! The Quest for Gravity',
    'Carmageddon: Max Damage',
    'Carmen Sandiego Adventures in Math: The Big Ben Burglary',
    'Carmen Sandiego Adventures in Math: The Lady Liberty Larceny',
    'Carnival Games: Monkey See, Monkey Do',
    'Carnivores: Dinosaur Hunter HD',
    'Cars 2',
    'Cartoon Network: Punch Time Explosion',
    'Cartoon Network: Punch Time Explosion XL',
    "Casey's Contraptions",
    'Castle Conqueror -- Against',
    'Castle Conqueror -- Heroes',
    'Castle Conqueror -- Revolution',
    'Castle of Illusion Starring Mickey Mouse',
    'CastleStorm',
    'Castlevania: Harmony of Despair',
    'Castlevania: Lords of Shadow 2',
    'Castlevania: Lords of Shadow -- Mirror of Fate',
    'Catherine',
    'Catrap',
    'Cave Story 3D',
    'Chantelise: A Tale of Two Sisters',
    'Chaos Heroes Online',
    'Chaos Rings II',
    'Charlie Murder',
    'Chasing Aurora',
    'Chibi-Robo!: Zip Lash',
    'Chicken Balls',
    'Child of Eden',
    'Child of Light',
    'Chime Super Deluxe',
    'Chivalry: Deadliest Warrior',
    'Chivalry: Medieval Warfare',
    'Choplifter HD',
    'Christmas Wonderland',
    'Chronicles of Vampires: Origins',
    'Chrono Trigger',
    'Chronos',
    'Cities in Motion',
    'Cities in Motion 2',
    'Cities: Skylines',
    'Cities: Skylines -- After Dark',
    'Citizens of Earth',
    'City of Secrets',
    'Closure',
    'Cloudberry Kingdom',
    'Clumsy Bob',
    'Cobalt',
    'Code Name S.T.E.A.M. -- Strike Team Eliminating the Alien Menace',
    'Code of Princess',
    'Colors! 3D',
    'Colour Bind',
    'Combat of Giants: Dinosaurs 3D',
    'Come On! Heroes',
    "Comedy Central's Indecision Game",
    'Commando (Arcade)',
    'Company of Heroes 2',
    'Company of Heroes 2: Ardennes Assault',
    'Company of Heroes 2: The British Forces',
    'Conduit 2',
    'Consortium',
    'Continue?9876543210',
    'Continuity 2',
    'Contrast',
    'Contre Jour',
    'Corpse Party',
    'Corpse Party: Book of Shadows',
    'Cortex Command',
    'Costume Quest',
    'Costume Quest 2',
    'Counter-Strike: Global Offensive',
    'Counterspy',
    'Cover Orange',
    'Cowboys & Aliens: Silver City Defense',
    'Craft the World',
    'Crasher',
    'Crashmo',
    'Crazy Hamster',
    'Crazy Machines Elements',
    'Crazy Taxi',
    'Crimson Dragon',
    'Crimsonland',
    'Critical Mass',
    'Crusader Kings II',
    'Crypt of the Necrodancer',
    'Crysis',
    'Crysis 2',
    'Crysis 3',
    'Crystal Caverns of Amon-Ra',
    'Cthulhu Saves the World',
    'Cubic Ninja',
    'Cut The Rope 2',
    'Cut The Rope: Experiments',
    'Cut the Rope',
    'D4',
    'DC Universe Online',
    'DCS: A-10C Warthog',
    'Dance Central 2',
    'Dance Central 3',
    'Dance Central Spotlight',
    'DanceDanceRevolution',
    'Dangerous Golf',
    'Darius Twin',
    'Dark',
    'Dark Lords',
    'Dark Souls',
    'Dark Souls (Prepare to Die Edition)',
    'Dark Souls II',
    'Dark Souls II: Crown of the Old Iron King',
    'Dark Souls II: Crown of the Sunken King',
    'Dark Souls III',
    'Darkest Dungeon',
    'Darksiders II',
    'Darksiders II: Deathinitive Edition',
    'Darkspore',
    'Darkstalkers Resurrection',
    'Datura',
    'Day of the Tentacle: Remastered',
    'Daylight',
    'Daytona USA',
    'Dead Block',
    'Dead Island',
    'Dead Island Riptide',
    'Dead Island: Definitive Collection',
    "Dead Man's Draw",
    'Dead Nation: Apocalypse Edition',
    'Dead Rising 2: Off the Record',
    'Dead Rising 3',
    'Dead Rising Triple Pack',
    'Dead Space 2',
    'Dead Space 2 (Limited Edition)',
    'Dead Space 2: Severed',
    'Dead Space 3',
    'Dead Space 3: Awakened',
    'Dead Space Extraction',
    'Dead Space [mobile version]',
    'Dead Star',
    'Dead State',
    'Dead or Alive 5',
    'Dead or Alive 5: Last Round',
    'Dead or Alive Dimensions',
    'Deadfall Adventures',
    'Deadliest Warrior: Legends',
    'Deadlight',
    "Deadly Premonition: The Director's Cut",
    'Deadpool',
    'Dear Esther',
    'Death Rally',
    'Defenders of Ardania',
    'Defense Grid 2',
    'Defense of the Middle Kingdom',
    'Defiance',
    'Defy Gravity Extended',
    'Delbo',
    "Demon's Score",
    'Depth',
    'Derrick the Deathfin',
    'Destiny',
    'Destiny: House of Wolves',
    'Destiny: The Dark Below',
    'Destiny: The Taken King',
    'Deus Ex: Human Revolution',
    "Deus Ex: Human Revolution -- Director's Cut",
    'Deus Ex: Human Revolution -- The Missing Link',
    'Deus Ex: Mankind Divided',
    'Deus Ex: The Fall',
    'Device 6',
    'Devil Daggers',
    'Devil May Cry 4 -- Special Edition',
    'Devil May Cry 4 Refrain',
    'Devil May Cry HD Collection',
    'Devil Summoner: Soul Hackers',
    "Devil's Attorney",
    "Devil's Third",
    'Diablo III',
    'Diablo III: Reaper of Souls',
    'Diablo III: Ultimate Evil Edition',
    'Diabolical Pitch',
    'Diaspora: Shattered Armistice',
    "Dillon's Rolling Western",
    "Dillon's Rolling Western: The Last Ranger",
    'Dino D-Day',
    'Dirt 3',
    'Dirt Rally',
    'Dirt Showdown',
    'Disgaea 3: Absence of Detention',
    'Disgaea 4: A Promise Unforgotten',
    'Disgaea 5: Alliance of Vengeance',
    'Disgaea D2: A Brighter Darkness',
    'Dishonored',
    'Dishonored: Definitive Edition',
    'Dishonored: The Brigmore Witches',
    'Dishonored: The Knife of Dunwall',
    'Disney Epic Mickey 2: The Power of Two',
    'Disney Epic Mickey: Power of Illusion',
    'Disney Fantasia: Music Evolved',
    'Disney Infinity',
    'Disney Infinity -- PC Game',
    'Disney Infinity: 2.0 Edition -- Marvel Super Heroes',
    'Disney Infinity: 2.0 Edition -- Toy Box Starter Pack',
    'Disney Infinity: 3.0 Edition',
    'Disney Universe',
    'Dissidia 012 Final Fantasy',
    'Divekick',
    'Divinity II: The Dragon Knight Saga',
    'Divinity: Dragon Commander',
    'Divinity: Original Sin',
    'Divinity: Original Sin -- Enhanced Edition',
    'DmC: Devil May Cry',
    'DmC: Devil May Cry -- Definitive Edition',
    'Doctor Who: The Eternity Clock',
    'DodoGo! Robo',
    'Doki-Doki Universe',
    'Dokuro',
    'Dollar Dash',
    'Don Bradman Cricket',
    'Don Bradman Cricket 14',
    "Don't Starve",
    'Donkey Kong',
    'Donkey Kong Country Returns 3D',
    'Donkey Kong Country: Tropical Freeze',
    'Doodle Fit',
    'Doom',
    'Doom 3: BFG Edition',
    'DotMan',
    'Dota 2',
    'Double Bloob',
    'Double Dragon',
    'Double Dragon: Neon',
    'Dr. Luigi',
    'Dragon Age II',
    'Dragon Age II -- Legacy',
    'Dragon Age II -- Mark of the Assassin',
    'Dragon Age: Inquisition',
    'Dragon Age: Inquisition -- Jaws of Hakkon',
    'Dragon Age: Inquisition -- The Descent',
    'Dragon Age: Inquisition -- Trespasser',
    'Dragon Ball Xenoverse',
    'Dragon Ball Z: Battle of Z',
    'Dragon Ball Z: Ultimate Tenkaichi',
    'Dragon Fantasy Book II',
    'Dragon Nest',
    'Dragon Quest Heroes',
    'Dragon Quest Monsters: Joker 2',
    'Dragon Quest VI: Realms of Revelation',
    'Dragon Quest VII: Fragments of the Forgotten Past',
    "Dragon's Crown",
    "Dragon's Dogma",
    "Dragon's Dogma: Dark Arisen",
    "Dragon's Prophet",
    'Drakengard 3',
    "Drakengard 3 (Collector's Edition)",
    'Drakerider',
    'Dream Track Nation',
    'Dream Trigger 3D',
    'Dreamcast Collection',
    'Dreamfall Chapters',
    'Driveclub',
    'Driver: San Francisco',
    'DuckTales Remastered',
    'Duke Nukem Forever',
    'Dungelot',
    'Dungeon Defenders',
    'Dungeon Hunter 4',
    'Dungeon Hunter: Alliance',
    'Dungeon Siege III',
    'Dungeon Twister',
    'Dungeon Village',
    'Dungeon of the Endless',
    'Dungeonland',
    'Dungeons',
    'Dungeons 2',
    'Dungeons & Dragons: Chronicles of Mystara',
    'Dungeons of Dredmor',
    'Dust 514',
    'Dust: An Elysian Tail',
    'Dustforce',
    'Dyad',
    'Dying Light',
    'Dying Light: The Following',
    'Dynasty Warriors 7',
    'Dynasty Warriors 7 Xtreme Legends',
    'Dynasty Warriors 7: Empires',
    'Dynasty Warriors 8',
    'Dynasty Warriors Next',
    'Dynasty Warriors: Gundam 3',
    'Dynasty Warriors: Gundam Reborn',
    'E.Y.E.: Divine Cybermancy',
    'EA Sports UFC',
    'EA Sports UFC 2',
    'ESPN Sports Connection',
    'Early Bird',
    'Earth Defense Force 2025',
    'EarthBound',
    'Earthbound Beginnings',
    'Edge of Nowhere',
    "Edna & Harvey: Harvey's New Eyes",
    'El Shaddai: Ascension of the Metatron',
    'Elder Scrolls Online: Tamriel Unlimited',
    'Elite Forces: Unit 77',
    'Elite: Dangerous',
    'Endless Legend',
    'Endless Space',
    'Enemy Front',
    'Enter the Gungeon',
    'Entwined',
    'Epoch',
    'Escape Dead Island',
    'Escape Goat',
    'Escape Plan',
    'Escape Trick: Convenience Store',
    'Escape Trick: Ninja Castle',
    'EscapeVektor: Chapter 1',
    'Ether One',
    'Etrian Odyssey 2 Untold: The Fafnir Knight',
    'Etrian Odyssey IV: Legends of the Titan',
    'Etrian Odyssey Untold: The Millennium Girl',
    'Eufloria',
    'Europa Universalis IV',
    'Everybody Dance',
    'Everybody’s Gone to the Rapture',
    'Evolve',
    'Exed Exes (Arcade)',
    'Expand',
    'Explodemon!',
    'Extreme Hangman 2',
    'F1 2011',
    'F1 2012',
    'F1 2013',
    'F1 2015',
    'F1 2016',
    'F1 Race Stars',
    'F.E.A.R. 3',
    'FAST Racing Neo',
    'FIFA 14',
    'FIFA 15',
    'FIFA 16',
    'FIFA 17',
    'FIFA Soccer 12',
    'FIFA Soccer 12 [3DS Edition]',
    'FIFA Soccer 13',
    'FIFA Soccer [PlayStation Vita edition]',
    'FIFA Street',
    'FTL: Faster Than Light',
    'Fable Anniversary',
    'Fable Heroes',
    'Fable III',
    "Fable III: Traitor's Keep",
    'Fable: The Journey',
    'Faery: Legends Of Avalon',
    'Fahrenheit: Indigo Prophecy Remastered',
    'Fairy Fencer F',
    'Fallen Enchantress',
    'Fallen Enchantress: Legendary Heroes',
    'Fallout 4',
    'Fallout 4: Automatron',
    'Fallout 4: Contraptions',
    'Fallout 4: Far Harbor',
    'Fallout 4: Nuka World',
    'Fallout 4: Vault-Tec Workshop',
    'Fallout 4: Wasteland Workshop',
    'Fallout Shelter',
    'Fallout: New Vegas -- Dead Money',
    'Fallout: New Vegas -- Honest Hearts',
    'Fallout: New Vegas -- Lonesome Road',
    'Fallout: New Vegas -- Old World Blues',
    'Family Guy: Back to the Multiverse',
    'Fantastic Pets',
    'Fantasy Life',
    'Far Cry 3',
    'Far Cry 3: Blood Dragon',
    'Far Cry 4',
    'Far Cry 4: Valley of the Yetis',
    'Far Cry Primal',
    'Farm Frenzy',
    'Farming Simulator 2013',
    'Fast & Furious: Showdown',
    'Fatal Frame: Deep Crimson Butterfly',
    'Fatal Frame: Maiden of the Black Water',
    'Fates Forever',
    'Faxanadu',
    'Feed Me Oil',
    'Fenix Rage',
    'Fez',
    'Fieldrunners 2',
    'Fight Night Champion',
    'Fighter Within',
    'Final Fantasy Dimensions',
    'Final Fantasy Explorers',
    'Final Fantasy III (SNES)',
    'Final Fantasy IV: The Complete Collection',
    'Final Fantasy Type-0 HD',
    'Final Fantasy X / X-2 HD Remaster',
    'Final Fantasy X / X-2 HD Remaster (Limited Edition)',
    'Final Fantasy XIII-2',
    'Final Fantasy XIV Online: A Realm Reborn',
    'Final Fantasy XIV Online: Heavensward',
    'Final Fantasy: All The Bravest',
    'Final Fantasy: Record Keeper',
    'Final Fight',
    'Fire Emblem Awakening',
    'Fire Emblem Fates: Birthright',
    'Fire Emblem Fates: Conquest',
    'Fire Emblem Fates: Revelation',
    'Firefall',
    'Firewatch',
    'Fish Out of Water',
    'Fish Tank',
    'Fishing Resort',
    "Fist of the North Star: Ken's Rage 2",
    'Flappy Bird',
    'Flashback',
    'Flight Control',
    'Floe: A Little Bear Needs Your Help',
    'Flower',
    'Fluidity: Spin Cycle',
    'Food Processing',
    'Foosball 2012',
    'Football Manager 2012',
    'Football Manager 2013',
    'Football Manager 2014',
    'Football Manager 2015',
    'Football Manager Classic 2014',
    'Forge',
    'Fortix 2',
    'Fortune Street',
    'Forza Horizon',
    'Forza Horizon 2',
    'Forza Horizon 2 Presents Fast & Furious',
    'Forza Horizon 3',
    'Forza Motorsport 4',
    'Forza Motorsport 5',
    'Forza Motorsport 6',
    'Fossil Fighters: Champions',
    'Fray',
    'Freakyforms Deluxe: Your Creations, Alive!',
    'Freakyforms: Your Creations, Alive!',
    'Freedom Wars',
    'From Dust',
    'Frozen Cortex',
    'Frozen Synapse',
    'Frozen Synapse Prime',
    'Fru',
    'Fruit Ninja Kinect',
    'Fruit Ninja: Puss in Boots',
    'Full House Poker',
    'Funk of Titans',
    'Funky Barn',
    'Funky Smugglers',
    'Furi',
    'Furry Legends: Beginnings',
    'Fuse',
    'Fusion: Genesis',
    'GO Series: Fishing Resort',
    'Gabriel Knight: Sins of the Fathers -- 20th Anniversary Edition',
    "Gabrielle's Ghostly Groove 3D",
    'Galactic Civilizations III',
    'Galaga Legions DX',
    'Galak-Z',
    'Game & Wario',
    'Game & Watch Gallery',
    'Game of Thrones',
    'Game of Thrones: Episode 1 -- Iron From Ice',
    'Game of Thrones: Episode 2 -- The Lost Lords',
    'Game of Thrones: Episode 3 -- The Sword in the Darkness',
    'Game of Thrones: Episode 4 -- Sons of Winter',
    'Game of Thrones: Episode 5 -- A Nest Of Vipers',
    'Game of Thrones: Episode 6 -- The Ice Dragon',
    "Gargoyle's Quest",
    'Garshasp',
    'Gatling Gears',
    'Gauntlet',
    'Gauntlet: Slayer Edition',
    'Gears',
    'Gears of War 3',
    "Gears of War 3: Raam's Shadow",
    'Gears of War: Judgment',
    'Gears of War: Ultimate Edition',
    'Gemini Rue',
    'Gemini: Heroes Reborn',
    'Gesundheit',
    'Get Outta My Galaxy',
    'Gettysburg: Armored Warfare',
    'Ghost Mania',
    'Ghost Trick: Phantom Detective',
    'Ghostbusters',
    'Ghostbusters: Sanctum of Slime',
    "Ghosts 'N Goblins (Arcade)",
    'Girls Like Robots',
    'Glare',
    'Glory Days: Tactical Defense',
    'Gnomz',
    'Go Fetch! 2',
    'Go Series: Portable Shrine Wars',
    'Go Vacation',
    'Go! Go! Kokopolo: Harmonious Forest Revenge',
    'Goat Simulator',
    'God Mode',
    'God of War Collection',
    'God of War III Remastered',
    'God of War Origins',
    'God of War: Ascension',
    'Gods & Heroes: Rome Rising',
    'Gods Eater Burst',
    'Gods Will Be Watching',
    'Godzilla',
    'Golden Axe II',
    'GoldenEye 007: Reloaded',
    'Golf',
    'Gone Home',
    'Gotham City Impostors',
    'Gran Turismo 6',
    'Grand Prix Story',
    'Grand Slam Tennis 2',
    'Grand Theft Auto III',
    'Grand Theft Auto V',
    'Grand Theft Auto: San Andreas',
    'Grand Theft Auto: Vice City',
    'Gravity Ghost',
    'Gravity Guy 2',
    'Gravity Rush',
    'Gray Matter',
    'Great Big War Game',
    'Green Lantern: Rise of the Manhunters',
    'Grey Goo',
    'Grid 2',
    'Grid Autosport',
    'Grim Dawn',
    'Grim Fandango Remastered',
    'Groove Coaster',
    'Grow Home',
    'Grow Up',
    'Guacamelee!',
    'Guacamelee! Super Turbo Championship Edition',
    'Guardian Heroes',
    'Guardians of Middle-earth',
    'Guild Wars 2',
    'Guild Wars 2: Heart of Thorns',
    'Guild of Dungeoneering',
    'Guilty Gear XX Accent Core Plus',
    'Guilty Gear XX Accent Core Plus R',
    'Guilty Gear Xrd Sign',
    'Guitar Hero Live',
    'Gun Commando',
    'Guncraft',
    'Gunman Clive',
    'Gunpoint',
    'Guns of Icarus Online',
    'HTC Vive',
    "Hack 'n' Slash",
    'Half-Minute Hero: Super Mega Neo Climax Edition',
    'Halloween: Trick or Treat',
    'Halo 3: ODST [The Master Chief Collection]',
    'Halo 4',
    'Halo 4 (Limited Edition)',
    'Halo 5: Guardians',
    'Halo: Combat Evolved Anniversary',
    'Halo: Spartan Assault',
    'Halo: Spartan Strike',
    'Halo: The Master Chief Collection',
    "Hamilton's Great Adventure",
    'Hand of Fate',
    'Happy Action Theater',
    'Happy Wars',
    'Hard Corps: Uprising',
    'Hard Reset',
    'Hard West',
    'Hardware: Rivals',
    'HarmoKnight',
    'Harry Potter and the Deathly Hallows: Part 2',
    'Harvest Moon DS: The Tale of Two Towns',
    'Harvest Moon: A New Beginning',
    'Hatoful Boyfriend',
    'He-Man: The Most Powerful Game in the Universe',
    'Hearthstone: Heroes of WarCraft',
    'Hearts Spades Euchre',
    'Hearts of Iron IV',
    'Heavy Rain',
    'Hector: Badge of Carnage -- Episode 1: We Negotiate with Terrorists',
    'Hector: Badge of Carnage -- Episode 2',
    'Hector: Badge of Carnage -- Episode 3: Beyond Reasonable Doom',
    'Hell Yeah! Wrath of the Dead Rabbit',
    'Helldivers',
    'Her Story',
    'Hero Academy',
    'Heroes of Ruin',
    'Heroes of the Storm',
    'Hitman Go',
    'Hitman HD Trilogy',
    'Hitman: Absolution',
    'Hitman: Episode 1',
    'Hitman: Episode 2',
    'Hitman: Episode 3',
    'Hitman: Episode 4',
    'Hoard',
    'Hobo with a Shotgun',
    'Hohokum',
    'Hole In The Wall',
    'Hollywood Squares',
    'Home: A Unique Horror Adventure',
    'Homefront',
    'Homefront: The Revolution',
    'Hometown Story',
    'Homeworld Remastered Collection',
    'Homeworld: Deserts of Kharak',
    'Hoodwink',
    'Horizon',
    'Horizon Riders',
    'Horn',
    'Hot Shots Golf: World Invitational',
    'Hot Shots Shorties -- Bundle Pack',
    'Hot Springs Story',
    'Hotline Miami',
    'Hotline Miami 2: Wrong Number',
    'House M.D. -- Episode 2: Blue Meanie',
    'House M.D. -- Episode 3: Skull and Bones',
    'House M.D. -- Episode 4: Crashed',
    'House M.D. -- Episode 5: Under the Big Top',
    'How to Survive',
    'Human Fall Flat',
    "Hunted: The Demon's Forge",
    'Hustle Kings',
    'Hybrid',
    'Hydrophobia: Prophecy',
    'Hyper Light Drifter',
    'Hyperdimension Neptunia',
    'Hyperdimension Neptunia Re:Birth 1',
    'Hyperdimension Neptunia Victory',
    'Hyperdimension Neptunia: Producing Perfection',
    'Hyrule Warriors',
    'Hyrule Warriors Legends',
    'Hysteria Project 2',
    'I Am Alive',
    'I Am Bread',
    'I Am Setsuna',
    'IL-2 Sturmovik: Cliffs of Dover',
    'Ibb & Obb',
    'Ikachan',
    'Ilomilo',
    'Impossible Road',
    'InMomentum',
    'Inazuma Eleven',
    'Incredipede',
    'Infamous 2',
    'Infamous: Festival of Blood',
    'Infamous: First Light',
    'Infamous: Second Son',
    'Infestation: Survivor Stories',
    'Infinite Crisis',
    'Injustice: Gods Among Us',
    'Injustice: Gods Among Us -- Ultimate Edition',
    'Insanely Twisted Shadow Planet',
    'Inside',
    'Inside a Star-Filled Sky',
    'Insurgency',
    'Into the Dead',
    'Inversion',
    'Invisible Inc.',
    'Iron Brigade',
    'Iron Man 3: The Official Game',
    'J-Stars Victory VS.+',
    'Jak and Daxter Collection',
    'Jamestown: Legend of the Lost Colony',
    "Jazz: Trump's Journey",
    'Jazzpunk',
    'JellyCar 2',
    "Jeremy McGrath's Offroad",
    "Jerry Rice & Nitus' Dog Football",
    'Jet Set Go',
    'Jet Set Radio',
    'Jetpack Joyride',
    'Jewel Keepers: Easter Island',
    'Jikandia: The Timeless Land',
    "JoJo's Bizarre Adventure HD",
    "JoJo's Bizarre Adventure: All Star Battle",
    'Joe Danger',
    'Joe Danger Infinity',
    'Joe Danger: Special Edition',
    'Joe Danger: The Movie',
    'Jonah Lomu Rugby Challenge',
    'Jotun',
    'Journey',
    'Jurassic Park: The Game',
    'Just Cause 3',
    'Just Dance 3',
    'Just Dance 4',
    'Just Dance 2014',
    'Just Dance 2015',
    'Just Jam',
    'Just SING! 80s Collection',
    'Just SING! Christmas Vol. 3',
    'Kalimba',
    'Kami Retro',
    'Kentucky Route Zero: Act 1',
    'Kentucky Route Zero: Act 2',
    'Kentucky Route Zero: Act 4',
    'Kerbal Space Program',
    "Ketzal's Corridors",
    'Kick & Fennick',
    'KickBeat',
    'Kid Icarus Uprising',
    'Killer Instinct',
    'Killer is Dead',
    'Killzone 3',
    'Killzone: Mercenary',
    'Killzone: Shadow Fall',
    'Kinect Disneyland Adventures',
    'Kinect Party',
    'Kinect Rush: A Disney Pixar Adventure',
    'Kinect Sports Rivals',
    'Kinect Sports: Season 2',
    'Kinect: Star Wars',
    'King Arthur II: The Role-Playing Wargame',
    'King of Fighters XIV',
    "King's Quest -- Episode 1: A Knight to Remember",
    "King's Quest -- Episode 2: Rubble without a Cause",
    'Kingdom',
    'Kingdom Hearts 3D: Dream Drop Distance',
    'Kingdom Hearts HD 1.5 ReMIX',
    'Kingdom Hearts HD II.5 ReMIX',
    'Kingdom Hearts: Re:coded',
    'Kingdom Rush',
    'Kingdoms of Amalur: Reckoning',
    'Kingdoms of Amalur: Reckoning -- The Legend of Dead Kel',
    'Kirby and the Rainbow Curse',
    "Kirby's Dream Land",
    "Kirby's Return to Dream Land",
    'Kirby: Mass Attack',
    'Kirby: Planet Robobot',
    'Kirby: Triple Deluxe',
    'Knack',
    'Knights Contract',
    'Knights of Pen & Paper II',
    'Knock-Knock',
    "Kona's Crate",
    'Krater',
    'Kung Fu Dragon',
    'Kung Fu Panda 2',
    'Kyotokei',
    'L.A. Noire',
    'L.A. Noire The Complete Edition',
    'L.A. Noire: Reefer Madness',
    'LEGO Batman 2: DC Super Heroes',
    'LEGO Batman 3: Beyond Gotham',
    'LEGO City Undercover: The Chase Begins',
    'LEGO City: Undercover',
    'LEGO Dimensions',
    'LEGO Harry Potter: Years 5-7',
    'LEGO Jurassic World',
    'LEGO Marvel Super Heroes',
    "LEGO Marvel's Avengers",
    'LEGO Pirates of the Caribbean: The Video Game',
    'LEGO Star Wars III: The Clone Wars',
    'LEGO Star Wars: The Force Awakens',
    'LEGO Star Wars: The Yoda Chronicles',
    'LEGO The Lord of the Rings',
    'LEGO The Lord of the Rings [Portable]',
    'LEGO: The Hobbit',
    'Labyrinth Legends',
    'Land-a Panda',
    'Lara Croft Go',
    'Lara Croft and the Temple of Osiris',
    'Layers of Fear',
    'League of Evil',
    'League of Evil 2',
    'League of Legends',
    'Leedmees',
    'Left 4 Dead 2: Cold Stream',
    'Legasista',
    'Legend of Grimrock',
    'Legend of Grimrock II',
    'Legends of Aethereus',
    'Legends of Dawn',
    'Legends of Eisenwald',
    'Leisure Suit Larry Reloaded',
    "Let's Create! Pottery",
    "Let's Fish! Hooked On",
    "Let's Golf 3D",
    'Leviathan: Warships',
    'Lichdom: Battlemage',
    'Life is Strange -- Episode 1: Chrysalis',
    'Life is Strange -- Episode 2: Out of Time',
    'Life is Strange -- Episode 3: Chaos Theory',
    'Life is Strange -- Episode 4: Dark Room',
    'Lightning Returns: Final Fantasy XIII',
    'Lili: Child of Geos',
    'Limbo',
    'Liqua Pop',
    'Little Chomp',
    'Little Deviants',
    'Little Inferno',
    'LittleBigPlanet 2',
    'LittleBigPlanet 3',
    'LittleBigPlanet Karting',
    'LittleBigPlanet PS Vita',
    'LittleBigPlanet PS Vita -- Marvel Super Hero Edition',
    'Loadout',
    "Lock 'n' Chase",
    'LocoCycle',
    'Lollipop Chainsaw',
    'London 2012: The Official Video Game of the Olympic Games',
    'Lone Survivor',
    'Lone Survivor (Director’s Cut)',
    'Lords of the Fallen',
    'Lost Dimension',
    'Lost Planet 3',
    'Lost in Shadow',
    'Lovers in a Dangerous Spacetime',
    'Lucius',
    "Lucky's Tale",
    'Luftrausers',
    "Luigi's Mansion: Dark Moon",
    'Lumines: Electronic Symphony',
    'Luxor HD',
    'MANOS: The Hands of Fate',
    'MLB 11: The Show',
    'MLB 12: The Show',
    'MLB 13: The Show',
    'MLB 14: The Show',
    'MLB 15: The Show',
    'MLB Bobblehead Pros',
    'MLB The Show 16',
    'MX vs. ATV Alive',
    'Machinarium',
    'Mad Max',
    'Madden NFL 12',
    'Madden NFL 13',
    'Madden NFL 15',
    'Madden NFL 16',
    'Madden NFL 17',
    'Madden NFL 25',
    'Madden NFL Football',
    'Mage Gauntlet',
    'Magic 2015 -- Duels of the Planewalkers',
    'Magic: The Gathering -- Duels of the Planeswalkers 2012',
    'Magic: The Gathering -- Duels of the Planeswalkers 2013',
    'Magic: The Gathering -- Duels of the Planeswalkers 2014',
    'Magical Whip: Wizards of Phantasmal Forest',
    'Magicka',
    'Magicka 2',
    'Magicka: Wizard Wars',
    'Magnetic: Cage Closed',
    'Magrunner: Dark Pulse',
    'Major League Baseball 2K11',
    'Major League Baseball 2K12',
    'Major League Baseball 2K13',
    'Major Mayhem',
    'Make-Up & Style',
    'Malicious',
    'Man of Steel',
    'Man of Steel HD',
    'March of the Eagles',
    'Mario & Luigi: Dream Team',
    'Mario & Luigi: Paper Jam',
    'Mario & Sonic at the London 2012 Olympic Games',
    'Mario & Sonic at the Sochi 2014 Olympic Winter Games',
    'Mario Golf World Tour',
    'Mario Kart 7',
    'Mario Kart 8',
    'Mario Party 9',
    'Mario Party 10',
    'Mario Party: Island Tour',
    'Mario Sports Mix',
    'Mario Tennis Open',
    'Mario Tennis: Ultra Smash',
    'Mario and Donkey Kong: Minis on the Move',
    'Mario vs. Donkey Kong: Tipping Stars',
    "Mario's Picross",
    'Mark of the Ninja',
    'Mars: War Logs',
    "Maru's Mission",
    'Marvel Heroes',
    'Marvel Puzzle Quest: Dark Reign',
    'Marvel Vs. Capcom 3: Fate of Two Worlds',
    'Marvel vs. Capcom Origins',
    "Marvel's The Avengers: Battle For Earth",
    'Mass Effect',
    'Mass Effect 2',
    'Mass Effect 2: Arrival',
    'Mass Effect 3',
    'Mass Effect 3 (Special Edition)',
    'Mass Effect 3: Citadel',
    'Mass Effect 3: Leviathan',
    'Mass Effect Infiltrator',
    'Massive Chalice',
    'Master Reboot',
    'Master of Orion',
    'Max & the Magic Marker',
    'Max Payne',
    'Max Payne 3',
    'Max Payne 3 (Special Edition)',
    'Max: The Curse of Brotherhood',
    'MechWarrior Online',
    'Medal of Honor Warfighter',
    "Medieval Moves: Deadmund's Quest",
    'Mega Mall Story',
    'Mega Man 5',
    'Mega Man Legacy Collection',
    'Mega Man X',
    "Mega Man: Dr. Wily's Revenge",
    'Men Of War: Vietnam',
    'Mercenary Kings',
    'Mercury Hg',
    'Metal Gear Rising: Revengeance',
    'Metal Gear Solid 3D Snake Eater',
    'Metal Gear Solid HD Collection',
    'Metal Gear Solid V: Ground Zeroes',
    'Metal Gear Solid V: The Phantom Pain',
    'Metrico',
    'Metro: Last Light',
    'Metro: Redux',
    'Metroid II: Return of Samus',
    'Metroid Prime: Federation Force',
    'Miasmata',
    'Michael Jackson: The Experience',
    'Michael Jackson: The Experience HD',
    'MicroBot',
    'Micromon',
    'Microsoft Flight',
    'Middle-earth: Shadow of Mordor',
    'Middle-earth: Shadow of Mordor: The Bright Lord',
    'Midnight Star',
    'Midway Arcade Origins',
    'Might & Magic Heroes VI',
    'Might & Magic Heroes VII',
    'Might and Magic X Legacy',
    'Might and Magic: Clash of Heroes',
    'Mighty Gunvolt',
    'Mighty Milky Way',
    'Mighty No. 9',
    "Mighty No. 9 (Collector's Edition)",
    'Mighty Switch Force',
    'Mind Zero',
    'Mindjack',
    'Minecraft',
    'Minecraft -- Pocket Edition',
    'Minecraft: Story Mode -- Episode 1: The Order of the Stone',
    'Minecraft: Story Mode -- Episode 2: Assembly Required',
    'Minecraft: Story Mode -- Episode 3: The Last Place You Look',
    'Minecraft: Story Mode -- Episode 4: A Block and a Hard Place',
    'Miner Wars 2081',
    'Minigore 2: Zombies',
    'Minimum',
    'MinoMonsters',
    'Minute to Win It',
    "Mirror's Edge Catalyst",
    'Mittens',
    'ModNation Racers: Road Trip',
    'Modern Combat 3: Fallen Nation',
    'Modern Combat 4: Zero Hour',
    'Monaco',
    'Monochrome Racing',
    'Monster Hunter 3 Ultimate',
    'Monster Hunter 4 Ultimate',
    'Monster Hunter Generations',
    'Monster Monpiece',
    'Monster Tale',
    'Monsters Inc. Run',
    'Moon Diver',
    'Mortal Kombat',
    'Mortal Kombat Arcade Kollection',
    'Mortal Kombat X',
    'MotionSports Adrenaline',
    'Moto Extreme',
    'MotoHeroz',
    'Motocross Madness',
    'MotorStorm Apocalypse',
    'MotorStorm RC',
    'Mount & Blade: Warband',
    'Mount & Blade: With Fire & Sword',
    'MouseCraft',
    'MovieCat',
    'Mr. Crab',
    'Mr. Ninja',
    'Ms. Pac-Man',
    'Ms. Splosion Man',
    'Mugen Souls',
    'Muramasa Rebirth',
    'Murasaki Baby',
    'Murdered: Soul Suspect',
    'Mushroom 11',
    'Mutant Mudds',
    'Mutant Mudds Deluxe',
    'My Asian Farm',
    'My Australian Farm',
    'Mystery Case Files: The Malgrave Incident',
    'NASCAR The Game 2011',
    'NBA 2K12',
    'NBA 2K12: Legends Showcase',
    'NBA 2K13',
    'NBA 2K14',
    'NBA 2K15',
    'NBA 2K16',
    'NBA 2K17',
    'NBA Jam',
    'NBA Jam: On Fire Edition',
    'NBA Live 14',
    'NBA Live 15',
    'NBA Live 16',
    'NCAA Football 12',
    'NCAA Football 13',
    'NCAA Football 14',
    'NCIS: The Game',
    'NES Remix',
    'NES Remix 2',
    'NFL Blitz',
    'NHL 12',
    'NHL 13',
    'NHL 14',
    'NHL 15',
    'NHL 16',
    'NHL 17',
    'Nancy Drew: The Deadly Device',
    'Nano Assault Neo',
    'Narco Terror',
    'Naruto Shippuden: Kizuna Drive',
    'Naruto Shippuden: Ultimate Ninja Impact',
    'Naruto Shippuden: Ultimate Ninja Storm 3',
    'Naruto Shippuden: Ultimate Ninja Storm 4',
    'Naruto Shippuden: Ultimate Ninja Storm Generations',
    'Naruto: Powerful Shippuden',
    'Natural Doctrine',
    'Natural Selection 2',
    'Naughty Bear: Panic in Paradise',
    'Necropolis',
    'Need for Speed',
    'Need for Speed Most Wanted',
    'Need for Speed Most Wanted U',
    'Need for Speed Rivals',
    'Need for Speed: The Run',
    'Neo Scavenger',
    'NeverDead',
    'Neverwinter',
    'New Bust-A-Move',
    "New Little King's Story",
    'New Orbit',
    'New Super Luigi U',
    'New Super Luigi U (Nintendo eShop Edition)',
    'New Super Mario Bros. 2',
    'New Super Mario Bros. U',
    'Nexuiz',
    'Ni no Kuni: Wrath of the White Witch',
    "Nickelodeon's Teenage Mutant Ninja Turtles",
    'Nidhogg',
    'NightSky',
    'Ninja Fishing',
    'Ninja Gaiden III',
    "Ninja Gaiden III: Razor's Edge",
    'Ninja Gaiden Sigma 2 Plus',
    'Ninja Gaiden Sigma Plus',
    'Nintendo Land',
    'Nintendogs + Cats: French Bulldog & New Friends',
    'Nintendogs + Cats: Golden Retriever & New Friends',
    'Nintendogs + Cats: Toy Poodle & New Friends',
    "No Man's Sky",
    "No More Heroes: Heroes' Paradise",
    'Not the Robots',
    'Nuclear Throne',
    'NyxQuest: Kindred Spirits',
    'ORC: Vengeance',
    'Oblitus',
    'Octodad: Dadliest Catch',
    'Oculus Rift',
    "Oddworld: New 'n' Tasty",
    "Oddworld: Stranger's Wrath HD",
    'Odin Sphere Leifthrasir',
    'Off-Road Drive',
    'Offworld Trading Company',
    'Oh! Edo Towns',
    'Oil Rush',
    'Oio',
    'Okabu',
    'Okami HD',
    'Okamiden',
    'OlliOlli',
    'OlliOlli 2: Welcome to OlliWood',
    'Omerta: City of Gangsters',
    'One Man Army',
    'One Piece: Burning Blood',
    'One Piece: Pirate Warriors',
    'One Piece: Pirate Warriors 3',
    'One Piece: Romance Dawn',
    'One Piece: Unlimited World Red',
    'Operation Flashpoint: Red River',
    'Orbital Gear',
    'Orcs Must Die',
    'Orcs Must Die 2',
    'Orgarhythm',
    'Ori and The Blind Forest',
    'Orion: Dino Beatdown',
    "Oscar's World Tour",
    'Otomedius Excellent',
    'Out of the Park Baseball 15',
    'Outland',
    'Outlast',
    'Outlast: Whistleblower',
    'Overwatch',
    'OxenFree',
    'Pac-Man',
    'Pac-Man & Galaga Dimensions',
    'Pac-Man Championship Edition 2',
    'Pac-Man: Championship Edition',
    'Pacific Rim',
    'Page Chronica',
    'Painkiller: Hell & Damnation',
    'Paint Splash',
    "Pandora's Tower",
    'Papa Sangre',
    'Paper Mario: Sticker Star',
    'Paper Titans',
    'Paper Wars: Cannon Fodder',
    'Papers, Please',
    'Papo & Yo',
    'Patapon 3',
    'Path of Exile',
    'PayDay 2',
    'PayDay 2: Crimewave Edition',
    'PayDay: The Heist',
    'Peggle 2',
    "Penny Arcade's On the Rain-Slick Precipice of Darkness 3",
    "Penny Arcade's On the Rain-slick Precipice of Darkness 4",
    'Persona 2: Innocent Sin',
    'Persona 4 Arena',
    'Persona 4 Arena Ultimax',
    'Persona 4 Golden',
    'Persona 4: Dancing All Night',
    'Persona Q: Shadow of the Labyrinth',
    'Phantom Breaker: Battle Grounds',
    'Phoenix Wright: Ace Attorney -- Dual Destinies',
    'Phoenix Wright: Ace Attorney -- Spirit of Justice',
    'Pickpawcket',
    'Pid',
    'Pikmin 3',
    'Pillar of Eternity: The White March - Part II',
    'Pillars of Eternity',
    'PilotWings Resort',
    'Pineapple Smash Crew',
    "Pinocchio's Puzzle",
    'Pirates of Black Cove',
    'Pitfall',
    'Pixel People',
    'Pixel Racer',
    'PixelJunk Monsters: Ultimate HD',
    'PixelJunk Shooter 2',
    'PixelJunk: SideScroller',
    'Plague Inc.',
    'PlanetSide 2',
    'Planetary Annihilation',
    'Plants vs. Zombies',
    'Plants vs. Zombies 2',
    'Plants vs. Zombies: Garden Warfare',
    'Plants vs. Zombies: Garden Warfare 2',
    'Play & Learn Chinese',
    'Play & Learn Spanish',
    'PlayStation All-Stars Battle Royale',
    'PlayStation Move Heroes',
    'Playstation Move: Ape Escape',
    'Pocket Clothier',
    'Pocket League Story',
    'Pokemon Alpha Sapphire Version',
    'Pokemon Battle Trozei',
    'Pokemon Black Version',
    'Pokemon Black Version 2',
    'Pokemon Conquest',
    'Pokemon Go',
    'Pokemon Omega Ruby Version',
    'Pokemon Rumble Blast',
    'Pokemon Trading Card Game Online',
    'Pokemon White Version',
    'Pokemon White Version 2',
    'Pokemon X',
    'Pokemon Y',
    'Pokken Tournament',
    'PokéPark 2: Wonders Beyond',
    'Pollen Count',
    'Pony Island',
    'Portal 2',
    'Postal III',
    'PowerUp Heroes',
    'Powerstar Golf',
    'Primal Carnage',
    'Prime World',
    'Primordia',
    'Prince of Persia Classic Trilogy HD',
    'Prinny 2: Dawn of Operation Panties, Dood!',
    'Prison Architect',
    'Pro Evolution Soccer 2011',
    'Pro Evolution Soccer 2012',
    'Pro Evolution Soccer 2013',
    'Pro Evolution Soccer 2014',
    'Pro Evolution Soccer 2015',
    'Pro Evolution Soccer 2016',
    'Pro Evolution Soccer 2017',
    'Pro Jumper! Guilty Gear Tangent',
    'Professor Layton and the Azran Legacy',
    'Professor Layton and the Last Specter',
    'Professor Layton and the Miracle Mask',
    'Professor Layton vs. Phoenix Wright',
    'Project CARS',
    'Project Highrise',
    'Project Spark',
    'Project X Zone',
    'Project X Zone 2',
    'Proteus',
    'Prototype 2',
    'Proun',
    "Pucca's Kisses Game",
    'Pudding Monsters',
    'Puddle',
    'Pulse: Volume One',
    'Punch Club',
    'Punch Quest',
    'Puppeteer',
    'Pure Chess',
    'Pushmo',
    'Puzzle & Dragons Z + Puzzle & Dragons Super Mario Bros. Edition',
    'Puzzle Craft',
    'Puzzle Dimension',
    'Puzzle Fever',
    'Puzzle Rocks',
    'Pyramids',
    'QUBE',
    'Quadrilateral Cowboy',
    'Quantum Break',
    'Quantum Conundrum',
    'Quarrel',
    'Quest Runner',
    'Quick Fill Q',
    'Quiz Climber',
    'R.I.P.D.: The Game',
    'RBI Baseball 14',
    'RBI Baseball 15',
    'Rabbids Land',
    'Radar Mission',
    'Radiant Historia',
    'Radiant Silvergun',
    'Rage',
    'Rage of the Gladiator',
    'Ragnarok Odyssey',
    'Railroad Story',
    'Rain',
    'Rainbow Moon',
    'Rainbow Six: Shadow Vanguard',
    'Rambo: The Video Game',
    'Ramps',
    "Randal's Monday",
    'Rare Replay',
    'Ratchet & Clank',
    'Ratchet & Clank Collection',
    'Ratchet & Clank: All 4 One',
    'Ratchet & Clank: Full Frontal Assault',
    'Ratchet & Clank: Into the Nexus',
    'Ravaged',
    "Raven's Cry",
    'Ravensword: Shadowlands',
    'Raving Rabbids: Alive & Kicking',
    'Raving Rabbids: Travel in Time 3D',
    'Rayman 3: Hoodlum Havoc HD',
    'Rayman 3D',
    'Rayman Fiesta Run',
    'Rayman Legends',
    'Rayman Origins',
    'Rayman: Jungle Run',
    'ReCore',
    'Real Boxing',
    'Real Racing 2 HD',
    'Real Racing 3',
    'Real Steel',
    'Realm of the Mad God',
    'Realms Of Ancient War',
    'Rebel Galaxy',
    'Record of Agarest War Zero',
    'Red Faction: Armageddon',
    'Red Faction: Battlegrounds',
    'Red Orchestra 2: Heroes of Stalingrad',
    'Red Orchestra 2: Rising Storm',
    'Redshirt',
    'Regular Show: Mordecai and Rigby in 8-Bit Land',
    'Rekoil',
    'Relic Rush',
    'Remember Me',
    'Remote Racers',
    'Renegade Ops',
    'Republique -- Episode 1: Exordium',
    'Republique -- Episode 2: Metamorphosis',
    'Resident Evil',
    'Resident Evil 4 HD',
    'Resident Evil 6',
    'Resident Evil -- CODE: Veronica X HD',
    'Resident Evil Mercenaries VS',
    'Resident Evil Revelations',
    'Resident Evil Revelations 2',
    'Resident Evil Revelations 2 -- Episode 1',
    'Resident Evil Revelations 2 -- Episode 2',
    'Resident Evil Revelations 2 -- Episode 3',
    'Resident Evil Revelations 2 -- Episode 4',
    'Resident Evil Zero',
    'Resident Evil: Operation Raccoon City',
    'Resident Evil: The Mercenaries 3D',
    'Resistance 3',
    'Resistance: Burning Skies',
    'Resogun',
    'Resogun Heroes',
    'Resonance',
    'Retro City Rampage',
    'Retro/Grade',
    'Retrovirus',
    'Reus',
    'Revenge of The Titans',
    'Rhythm Heaven Fever',
    'Rhythm Party',
    'Rick and Morty: Pocket Mortys',
    'Ricochet HD',
    'Ridge Racer',
    'Ridge Racer 3D',
    'Ridge Racer Accelerated HD',
    'Ridiculous Fishing: A Tale of Redemption',
    'Rift',
    'Rift: Storm Legion',
    'Rise of Immortals',
    'Rise of Incarnates',
    'Rise of Nightmares',
    'Rise of the Tomb Raider',
    'Rise of the Tomb Raider -- Baba Yaga: The Temple of the Witch',
    'Rise of the Tomb Raider -- Cold Darkness Awakened',
    'Rise of the Triad',
    'Risen 2: Dark Waters',
    'Risen 3: Titan Lords',
    'Risk: Factions',
    'Rival Turf',
    'Rive',
    'Road Blaster',
    'Road Not Taken',
    'RoboSockets',
    'Robot Unicorn Attack 2',
    'Roboto',
    'Rochard',
    'Rock Band 4',
    'Rock Band Blitz',
    'Rock of Ages',
    'Rocket League',
    'Rocketbirds: Hardboiled Chicken',
    'Rocksmith',
    'Rocksmith 2014',
    'Rogue Legacy',
    'Roller Coaster Rampage',
    'Rory McIlroy PGA Tour',
    'Rugby 15',
    'Rugby Challenge',
    'Rugby League Live 2',
    'Rugby League Live 3',
    'Rugby World Cup 2011',
    'Rugby World Cup 2015',
    'Run Roo Run',
    'Rune Factory 4',
    'Rune Factory: Tides of Destiny',
    'Runespell: Overture',
    "Rush'N Attack Ex-Patriot",
    'Ryse: Son of Rome',
    'Rytmik Retrobits',
    'S.C.A.T.: Special Cybernetic Attack Team',
    'SBK 2011',
    'SOCOM 4: U.S. Navy SEALs',
    'SOL: Exodus',
    'SSX',
    'Sacred 3',
    'Sacred Citadel',
    'Sacred Odyssey: Rise of Ayden',
    'Saint Seiya: Brave Soldiers',
    'Saints Row IV',
    'Saints Row IV: Gat Out of Hell',
    'Saints Row IV: Re-Elected & Gat Out of Hell',
    'Saints Row: The Third',
    'Sakura Samurai: Art of the Sword',
    'Salt and Sanctuary',
    'Sam & Max: Beyond Time and Space',
    'Samurai Bloodshow',
    'Samurai Gunn',
    'Samurai Sword Destiny',
    'Samurai Warriors Chronicles',
    'Sanctum 2',
    'ScaryGirl',
    'Scene It? Movie Night',
    'Screamride',
    'Screencheat',
    'Scribblenauts Remix',
    'Scribblenauts Unlimited',
    'Scribblenauts Unmasked: A DC Comics Adventure',
    'Scrolls',
    'Secret Ponchos',
    'Section 8: Prejudice',
    'Self-Defense Training Camp',
    'Serious Sam 3: BFE',
    'Serious Sam: Double D',
    'Serious Sam: The Random Encounter',
    'Sesame Street: Once Upon a Monster',
    'Severed',
    "Shad'O",
    'Shadow Harvest: Phantom Ops',
    'Shadow Warrior',
    'Shadowgate -- The Classic Adventure Re-Imagined',
    'Shadowgun',
    'Shadowrun Chronicles: Boston Lockdown',
    'Shadowrun Returns',
    'Shadowrun: Hong Kong',
    'Shadows of the Damned',
    'Shank 2',
    "Shantae and the Pirate's Curse",
    'Sharknado: The Video Game',
    'Sherlock Holmes: Crimes & Punishments',
    'Shift 2 Unleashed',
    'Shin Megami Tensei IV',
    'Shin Megami Tensei: Devil Survivor Overclocked',
    'Shinobi',
    'Shinobi III: Return of the Ninja Master',
    'Shinobido 2: Revenge of Zen',
    'Shoot Many Robots',
    'ShootMania Storm',
    'Shovel Knight',
    "Sid Meier's Civilization Revolution 2",
    "Sid Meier's Civilization V: Brave New World",
    "Sid Meier's Civilization V: Gods & Kings",
    "Sid Meier's Civilization: Beyond Earth",
    "Sid Meier's Civilization: Beyond Earth -- Rising Tide",
    "Sid Meier's Pirates!",
    "Sid Meier's Starships",
    'Side Pocket',
    'Sideway: New York',
    'Siege Hero',
    'Siesta Fiesta',
    'Silent Hill HD Collection',
    'Silent Hill: Book of Memories',
    'Silent Hill: Downpour',
    'SimCity',
    'SimCity: Cities of Tomorrow',
    'Simply Minesweeper',
    'Sine Mora',
    'Sing Party',
    'Sins of a Solar Empire: Rebellion',
    'Sir, You are Being Hunted',
    'Ski Safari',
    'Skullgirls',
    'Skulls of the Shogun',
    'Sky Gamblers: Storm Raiders',
    'Skydrift',
    'Skylanders Battlegrounds',
    'Skylanders Giants',
    "Skylanders Spyro's Adventure",
    'Skylanders SuperChargers',
    'Skylanders Swap Force',
    'Skylanders Trap Team',
    'Slam Bolt Scrappers',
    'Sleeping Dogs',
    'Sleeping Dogs: Definitive Edition',
    'Slender: The Arrival',
    'Slingo Supreme',
    'Sly Cooper: Thieves in Time',
    'Smart As...',
    'Smite',
    'Snapshot',
    'Sniper Elite III',
    'Sniper Elite V2',
    'Sniper: Ghost Warrior',
    'Sniper: Ghost Warrior 2',
    'Soccer Up',
    'Solar 2',
    'Solatorobo: Red The Hunter',
    'Soma',
    'SonSon (Arcade)',
    'Song of the Deep',
    'Sonic & All-Stars Racing Transformed',
    'Sonic Boom: Rise of Lyric',
    'Sonic Boom: Shattered Crystal',
    'Sonic CD',
    'Sonic Dash',
    'Sonic Generations',
    'Sonic Jump',
    'Sonic the Hedgehog 4: Episode II',
    'Sonic: Lost World',
    'Soul Sacrifice',
    'Soulcalibur V',
    'Sound Shapes',
    'Soundodger',
    'Sour Patch Kids: World Gone Sour',
    "South Park: Tenorman's Revenge",
    'South Park: The Stick of Truth',
    'Space Hulk',
    'Spacebase DF-9',
    'Spare Parts',
    'Spec Ops: The Line',
    'Special Forces: Team X',
    'Speedball 2 Evolution',
    'Spelunky',
    'Spider-Man: Edge of Time',
    'Spirit Camera: The Cursed Memoir',
    'Splatoon',
    'Splice: Tree of Life',
    "SpongeBob SquarePants: Plankton's Robotic Revenge",
    'SpongeBob SquigglePants',
    'Sports Champions 2',
    'Sportsfriends',
    'Sprinkle',
    'Spy Mouse',
    'Stacking',
    'Star Command',
    'Star Fox 64 3D',
    'Star Fox Guard',
    'Star Fox Zero',
    'Star Ocean: Integrity and Faithlessness',
    'Star Trek: The Game',
    'Star Wars Battlefront',
    'Star Wars Knights of the Old Republic',
    'Star Wars: The Old Republic',
    'Star Wars: The Old Republic -- Knights of the Fallen Empire',
    'Star Wars: The Old Republic -- Rise of the Hutt Cartel',
    'Star Wars: Uprising',
    'StarCraft II: Heart of the Swarm',
    'StarCraft II: Legacy of the Void',
    'StarDrive',
    'StarDrive 2',
    'StarDrone Extreme',
    'StarFront: Collision',
    'Starbound',
    'Starcraft II: Nova Covert Ops -- Mission Pack 1',
    'Starcraft II: Nova Covert Ops -- Mission Pack 2',
    'Stardew Valley',
    'Starhawk',
    'Starlight Inception',
    'State of Decay',
    'State of Decay: Year One Survival Edition',
    'Stealth Inc. 2: A Game of Clones',
    'Stealth Inc.: A Clone in the Dark',
    'SteamWorld Dig',
    'SteamWorld Heist',
    'Steel Battalion: Heavy Armor',
    'Steel Diver',
    'Steel Diver: Sub Wars',
    'Steins;Gate',
    'Stellaris',
    'Step Up',
    'Stick it to The Man',
    'Stickman BMX',
    'Storm',
    'Storm in a Teacup',
    'Story of Seasons',
    'Strange Rain',
    'Stratego: Next Edition',
    'Street Fighter III: Third Strike -- Online Edition',
    'Street Fighter V',
    'Street Fighter X Mega Man',
    'Street Fighter x Tekken',
    'StreetPass Flower Town',
    'StreetPass Mii Force',
    'StreetPass Monster Manor',
    "StreetPass Warrior's Way",
    'Streets of Rage 2',
    'Strider',
    'Strike Suit Zero',
    'Stronghold 3',
    'Styx: Master of Shadows',
    'Submerged',
    'Sumioni: Demon Arts',
    'SunFlowers',
    'Sunless Sea',
    'Sunset',
    'Sunset Overdrive',
    'Sunset Overdrive -- Mystery of the Mooil Rig',
    'Super Adventure Island 2',
    'Super Bonk',
    'Super Comboman',
    'Super Crate Box',
    'Super Hexagon',
    'Super House of Dead Ninjas',
    'Super Mario 3D Land',
    'Super Mario 3D World',
    'Super Mario Land',
    'Super Mario Land 2',
    'Super Mario Maker',
    'Super Mega Baseball',
    'Super Monday Night Combat',
    'Super Monkey Ball 3D',
    'Super Motherload',
    'Super Smash Bros. for Nintendo 3DS',
    'Super Smash Bros. for Wii U',
    'Super Stardust Delta',
    'Super Stickman Golf 2',
    'Super Street Fighter IV 3D Edition',
    'Super Street Fighter IV: Arcade Edition',
    'Super TIME Force',
    'Superbrothers: Sword & Sworcery EP',
    'Superhot',
    'Supremacy MMA',
    'Supreme League of Patriots',
    'Surge Deluxe',
    'Surgeon Simulator 2013',
    'Survivor',
    'Swarm',
    'Swing the Bat',
    'Sword & Sworcery EP',
    'Sword Art Online: Hollow Fragment',
    'Sword Art Online: Lost Song',
    'Sword Coast Legends',
    'Sword of the Stars II: Lords of Winter',
    'Swords & Soldiers',
    'Symphonica: Grand Maestro',
    'Symphony',
    'Syndicate',
    'Taco Master',
    'Tactics Ogre: Let Us Cling Together',
    'Takedown: Red Sabre',
    'Tales from Space: About a Blob',
    'Tales from Space: Mutant Blobs Attack',
    'Tales from the Borderlands -- Episode 1: Zer0 Sum',
    'Tales from the Borderlands -- Episode 2: Atlas Mugged',
    'Tales from the Borderlands -- Episode 3:  Catch a Ride',
    'Tales from the Borderlands -- Episode 4: Escape Plan Bravo',
    'Tales from the Borderlands -- Episode 5 The Vault of the Traveler',
    'Tales of Symphonia Chronicles',
    'Tales of Xillia',
    'Tales of Xillia 2',
    'Tales of Zestiria',
    'Tales of the Abyss',
    'Tank! Tank! Tank!',
    'Tapper World Tour',
    'Tearaway',
    'Tearaway Unfolded',
    'Tecmo Bowl Throwback [Mobile]',
    'Teenage Mutant Ninja Turtles: Danger of the Ooze',
    'Teenage Mutant Ninja Turtles: Mutants in Manhattan',
    'Teenage Mutant Ninja Turtles: Out of the Shadows',
    'Teenage Mutant Ninja Turtles: Rooftop Run',
    'Tekken 3D: Prime Edition',
    'Tekken Hybrid',
    'Tekken Tag Tournament 2',
    'Tekken Tag Tournament 2: Wii U Edition',
    'Teleglitch: Die More Edition',
    "Telltale Games' Poker Night 2",
    'Tembo the Badass Elephant',
    'Temple Run',
    'Tennis',
    'Tera: Rising',
    'Terraria',
    'Tesla Effect: A Tex Murphy Adventure',
    'Test Drive Unlimited 2',
    'Test Drive: Ferrari Racing Legends',
    'Tetris',
    'Tetris (EA)',
    'Tetris: Axis',
    'Tharsis',
    'That Dragon, Cancer',
    'The 3rd Birthday',
    'The Adventures of Tintin',
    'The Amazing Spider-Man',
    'The Amazing Spider-Man 2',
    'The Baconing',
    'The Banner Saga',
    'The Banner Saga 2',
    'The Banner Saga: Factions',
    "The Beginner's Guide",
    'The Binding of Isaac',
    'The Binding of Isaac: Rebirth',
    'The Black Eyed Peas Experience',
    'The Bureau: XCOM Declassified',
    'The Castle Doctrine',
    'The Cave',
    'The Crew',
    'The Cursed Crusade',
    'The Dark Knight Rises',
    'The Dark Meadow',
    'The Darkness II',
    'The Denpa Men 2: Beyond the Waves',
    'The Dishwasher: Vampire Smile',
    'The Earth Defense Force 2017 Portable',
    'The Earth Defense Force: Insect Armageddon',
    'The Elder Scrolls Online',
    'The Elder Scrolls V: Skyrim',
    'The Elder Scrolls V: Skyrim -- Dawnguard',
    'The Elder Scrolls V: Skyrim -- Dragonborn',
    'The Escapists',
    'The Evil Within',
    'The Evil Within: The Assignment',
    'The Evil Within: The Consequence',
    'The Evil Within: The Executioner',
    'The Expendables 2 Videogame',
    'The Fancy Pants Adventures',
    'The First Templar',
    'The Flame in the Flood',
    'The Golf Club',
    "The Golf Club: Collector's Edition",
    'The Guided Fate Paradox',
    'The Gunstringer',
    'The Haunted: Hells Reach',
    'The House of the Dead III',
    'The House of the Dead: Overkill -- Extended Cut',
    'The House of the Dead: Overkill -- The Lost Reels',
    'The Ico & Shadow of the Colossus Collection',
    'The Ignition Factor',
    'The Incredible Adventures of Van Helsing',
    'The Incredible Adventures of Van Helsing II',
    'The King of Fighters XIII',
    'The Kore Gang',
    'The LEGO Movie Videogame',
    'The Last Federation',
    'The Last Rocket',
    'The Last Story',
    'The Last of Us',
    'The Last of Us: Left Behind',
    'The Last of Us: Remastered',
    'The Legend of Heroes: Trails in the Sky',
    'The Legend of Korra',
    'The Legend of Zelda: A Link Between Worlds',
    'The Legend of Zelda: Four Swords Anniversary Edition',
    "The Legend of Zelda: Link's Awakening DX",
    "The Legend of Zelda: Majora's Mask 3D",
    'The Legend of Zelda: Ocarina of Time 3D',
    'The Legend of Zelda: Skyward Sword',
    'The Legend of Zelda: The Wind Waker HD',
    'The Legend of Zelda: The Wind Waker HD (Nintendo eShop Edition)',
    'The Legend of Zelda: Tri Force Heroes',
    'The Legend of Zelda: Twilight Princess HD',
    'The Lord of the Rings Online: Riders of Rohan',
    'The Lord of the Rings: War in the North',
    'The Lost Town: The Dust',
    'The Magic Circle',
    'The Mooniacs',
    'The Mystery of Whiterock Castle',
    'The Night of the Rabbit',
    'The Novelist',
    'The Order: 1886',
    'The Other Brothers',
    'The Park',
    'The Pinball Arcade',
    'The Political Machine 2012',
    'The Raven: Legacy of a Master Thief Chapter I: The Eye of the Sphinx',
    'The Raven: Legacy of a Master Thief Chapter II: Ancestry of Lies',
    'The Raven: Legacy of a Master Thief Chapter III: A Murder of Ravens',
    'The Room Three',
    'The Room Two',
    'The Secret World',
    'The Showdown Effect',
    'The Simpsons: The Arcade Game',
    'The Sims 3',
    'The Sims 3: Generations',
    'The Sims 3: Pets',
    'The Sims 3: Seasons',
    'The Sims 3: Supernatural',
    'The Sims 4',
    'The Sims Medieval',
    'The Sims Medieval: Pirates and Nobles',
    'The Sly Collection',
    'The Splatters',
    'The Stanley Parable',
    'The Starship Damrey',
    'The Sushi Spinnery',
    'The Swapper',
    'The Talos Principle',
    'The Technomancer',
    'The Turing Test',
    'The Unfinished Swan',
    'The Vanishing of Ethan Carter',
    'The Walking Dead -- Game of the Year Edition',
    'The Walking Dead: 400 Days',
    'The Walking Dead: A Telltale Game Series -- Season One',
    'The Walking Dead: A Telltale Game Series -- Season Two',
    'The Walking Dead: Assault',
    'The Walking Dead: Michonne -- Episode 1: In Too Deep',
    'The Walking Dead: Michonne -- Episode 2: Give No Shelter',
    'The Walking Dead: Michonne -- Episode 3: What We Deserve',
    'The Walking Dead: Season Two -- Episode 1: All That Remains',
    'The Walking Dead: Season Two -- Episode 2: A House Divided',
    "The Walking Dead: Season Two -- Episode 3: In Harm's Way",
    'The Walking Dead: Season Two -- Episode 4: Amid the Ruins',
    'The Walking Dead: Season Two -- Episode 5: No Going Back',
    'The Walking Dead: Survival Instinct',
    'The Walking Dead: The Game -- Episode 2: Starved For Help',
    'The Walking Dead: The Game -- Episode 3: Long Road Ahead',
    'The Walking Dead: The Game -- Episode 4: Around Every Corner',
    'The Walking Dead: The Game -- Episode 5: No Time Left',
    'The War of the Worlds',
    'The Witch and the Hundred Knight',
    'The Witcher 2: Assassins of Kings',
    'The Witcher 2: Assassins of Kings (Enhanced Edition)',
    'The Witcher 3: Wild Hunt',
    'The Witcher 3: Wild Hunt -- Blood and Wine',
    'The Witcher 3: Wild Hunt -- Hearts of Stone',
    'The Witcher Adventure Game',
    'The Witcher Battle Arena',
    'The Witness',
    'The Wolf Among Us: Episode 1 -- Faith',
    'The Wolf Among Us: Episode 2 -- Smoke and Mirrors',
    'The Wolf Among Us: Episode 3 -- A Crooked Mile',
    "The Wolf Among Us: Episode 4 -- In Sheep's Clothing",
    'The Wolf Among Us: Episode 5 -- Cry Wolf',
    'The Wonderful 101',
    'The World Ends with You: Solo Remix',
    'Theatre of War 3: Korea',
    'Theatrhythm Final Fantasy',
    'Theatrhythm Final Fantasy: Curtain Call',
    'They Bleed Pixels',
    'Thief',
    'Thirty Flights of Loving',
    'This War Of Mine',
    'Thomas Was Alone',
    'Thor: God of Thunder',
    'Threes',
    'Thunder Wolves',
    'Ticket to Ride',
    'Tiger Woods PGA Tour 12: The Masters',
    'Tiger Woods PGA Tour 13',
    'Tiger Woods PGA Tour 14',
    'Time and Eternity',
    "Tiny & Big: Grandpa's Leftovers",
    'Tiny Brains',
    'Tiny Wings',
    'Titan Attacks!',
    'Titan Souls',
    'Titanfall',
    "Titanfall (Collector's Edition)",
    'To the Moon',
    "Tobe's Vertical Adventure",
    'Toki Tori 2',
    'Tokyo Crash Mobs',
    'Tokyo Jungle',
    'Tokyo Mirage Sessions #FE',
    "Tom Clancy's Ghost Recon Phantoms",
    "Tom Clancy's Ghost Recon: Future Soldier",
    "Tom Clancy's Ghost Recon: Future Soldier (Signature Edition)",
    "Tom Clancy's Ghost Recon: Shadow Wars",
    "Tom Clancy's Rainbow Six Siege",
    "Tom Clancy's Splinter Cell 3D",
    "Tom Clancy's Splinter Cell Classic Trilogy HD",
    "Tom Clancy's Splinter Cell: Blacklist",
    "Tom Clancy's The Division",
    "Tom Clancy's The Division -- Underground",
    'Tomb Breaker',
    'Tomb Raider',
    'Tomb Raider Trilogy',
    'Tomb Raider: Definitive Edition',
    'Tomodachi Life',
    "Tony Hawk's Pro Skater 5",
    "Tony Hawk's Pro Skater HD",
    'Top Spin 4',
    'Torchlight',
    'Torchlight II',
    'Total War Battles: Shogun',
    'Total War: Attila',
    'Total War: Rome II',
    'Total War: Shogun 2',
    'Total War: Shogun 2 -- Fall of The Samurai',
    'Total War: Warhammer',
    'Touch My Katamari',
    'Toukiden: The Age of Demons',
    'TowerFall Ascension',
    'Toy Soldiers: Cold War',
    'TrackMania Turbo',
    'TrackMania: Build to Race',
    'Trackmania 2: Canyon',
    'Transformers Prime',
    'Transformers: Dark of the Moon',
    'Transformers: Dark of the Moon -- Autobots',
    'Transformers: Dark of the Moon -- Decepticons',
    'Transformers: Dark of the Moon -- Stealth Force Edition',
    'Transformers: Devastation',
    'Transformers: Fall of Cybertron',
    'Transformers: Rise of the Dark Spark',
    'Transistor',
    'Trapped Dead',
    'Trauma',
    'Trenches Generals',
    'Trials Evolution',
    'Trials Fusion',
    'Trials of the Blood Dragon',
    'Tribes: Ascend',
    'Trine 2',
    "Trine 2: Director's Cut",
    "Trinity: Souls of Zill O'll",
    'Triple Town',
    'Trollboarder',
    'Tropico 4',
    'Tropico 5',
    'True Skate',
    'Twisted Metal',
    'Two Worlds II',
    'Two Worlds II: Castle Defense',
    'TxK',
    'UEFA Euro 2012',
    'UFC Personal Trainer: The Ultimate Fitness System',
    'UFC Undisputed 3',
    'Ultimate Marvel Vs. Capcom 3',
    'Ultra Street Fighter IV',
    'Umbrella Corps',
    'Unchained Blades',
    "Uncharted 3: Drake's Deception",
    "Uncharted 4: A Thief's End",
    'Uncharted: Fight For Fortune',
    'Uncharted: Golden Abyss',
    'Uncharted: The Nathan Drake Collection',
    'Under Siege',
    'Undertale',
    'Unepic',
    'Unit 13',
    'Unravel',
    'Unstoppable Gorg',
    'Until Dawn',
    'VVVVVV',
    'Valiant Hearts: The Great War',
    'Valkyria Chronicles',
    'Valkyria Chronicles Remastered',
    'Valley',
    'Velocispider',
    'Velocity',
    'Velocity 2X',
    'Velocity Ultra',
    'Venetica',
    'Venture Towns',
    'Vessel',
    'Virginia',
    'Virtua Fighter 2',
    'Virtua Fighter 5 Final Showdown',
    'Virtua Tennis 4',
    'Virtua Tennis 4: World Tour Edition',
    'Volcano Escape',
    'Voltron: Defender of the Universe',
    'Volume',
    'WRC 2 FIA World Rally Championship',
    'WRC 3 FIA World Rally Championship',
    'WWE 2K14',
    'WWE 2K15',
    'WWE 2K16',
    "WWE '12",
    "WWE '13",
    'WWE All Stars',
    'Waking Mars',
    'War Pinball',
    'War Thunder',
    'War of the Roses',
    'War of the Vikings',
    'Warframe',
    'Wargame: AirLand Battle',
    'Wargame: European Escalation',
    'Wargame: Red Dragon',
    'Warhammer 40,000: Dawn of War II -- Retribution',
    'Warhammer 40,000: Kill Team',
    'Warhammer 40,000: Space Marine',
    'Warhammer Quest',
    'Warhammer: End Times -- Vermintide',
    'Warlock: Master of the Arcane',
    'Warp',
    'Warriors Orochi 3',
    'Warriors Orochi 3 Hyper',
    'Warriors: Legends of Troy',
    'Wasteland 2',
    "Wasteland 2: Director's Cut",
    'Wasteland Angel',
    'Watch Dogs',
    'Watch Dogs: Bad Blood',
    'Waves',
    'Way of the Samurai 4',
    'When Vikings Attack',
    'Where is my Heart?',
    "Where's My Water?",
    'Whispering Willows',
    'White Night',
    "Who's That Flying!?",
    'Wii Fit U',
    'Wii Party U',
    'Wii Play: Motion',
    'Wii Sports Club',
    'Wii Sports Club (Retail Edition)',
    'Wild Blood',
    'WildStar',
    'Wipeout In the Zone',
    'Wizardry: The Labyrinth of Lost Souls',
    'Wolfenstein: The New Order',
    'Wolfenstein: The Old Blood',
    'Wonderbook: Book  of Spells',
    'Word Searcher 4',
    'WordJong Arcade',
    'World Cruise Story',
    'World War Z',
    'World of Goo',
    'World of Tanks',
    'World of Warcraft: Legion',
    'World of Warcraft: Mists of Pandaria',
    'World of Warcraft: Warlords of Draenor',
    'World of Warplanes',
    'World of Warships',
    'Worms Crazy Golf',
    'Worms Revolution',
    'Worms WMD',
    'Wraithborne',
    'Wreckateer',
    'Writer Rumble',
    'X Rebirth',
    'X-Men: Battle of the Atom',
    'X-Men: Destiny',
    'XCOM 2',
    'XCOM 2: Alien Hunters',
    "XCOM 2: Shen's Last Gift",
    'XCOM: Enemy Unknown',
    'XCOM: Enemy Within',
    'XCOM: Enemy Within -- Commander Edition',
    'Xenoblade Chronicles',
    'Xenoblade Chronicles X',
    'Xenonauts',
    'Xeodrifter',
    'Xmas Puzzle',
    'Xotic',
    'Yaiba: Ninja Gaiden Z',
    'Yakuza 4',
    'Yakuza: Dead Souls',
    "Yar's Revenge",
    'Year Walk',
    'Yo-Kai Watch',
    'YooStar 2',
    "Yoshi's New Island",
    "Yoshi's Woolly World",
    "You Don't Know Jack",
    "You Don't Know Jack (2011)",
    'Young Justice: Legacy',
    'Your Doodles Are Bugged',
    'Your Shape: Fitness Evolved 2012',
    'Ys I & II Chronicles',
    'Ys: Memories of Celceta',
    "Yu-Gi-Oh! 5D's World Championship 2011: Over The Nexus",
    'Zack Zero',
    'Zeit 2',
    'Zen Pinball 3D',
    'Zeno Clash II',
    'Zenonia 3: The Midgard Story',
    "Zero Escape: Virtue's Last Reward",
    'Zero Time Dilemma',
    'Zombi',
    'ZombiU',
    'Zombie Apocalypse: Never Die Alone',
    'Zombie Gunship',
    'Zombie Parkour Runner',
    "Zombie Tycoon 2: Brainhov's Revenge",
    'Zone of the Enders HD Collection',
    'Zoo Tycoon',
    'Zoombies: Animales de la Muerte',
    'Zoonies: Escape from Makatu',
    "Zuma's Revenge",
    'Zumba Fitness World Party',
    'de Blob 2',
    'iBlast Moki 2',
    'iStunt 2',
]



"""Implements enums for a lot of methods.

Enums from this module are used in a lot of methods.
You should always import enums from this module if you want
behavior for the methods that differ from the default behavior.

You should never use your own enums in methods because in this case,
there no guarantee that you will get the result which you actually expected.

Below you can see an example of usage enums in methods of data providers.

Example:
    >>> from mimesis import Person
    >>> from mimesis.enums import Gender
    >>> person = Person()
    >>> person.full_name(gender=Gender.FEMALE)
    'Antonetta Garrison'
"""

from enum import Enum


class PortRange(Enum):
    """Represents port ranges.

    Value for a method ``Internet.port()`` which
    takes parameter ``port_range``.
    """

    ALL = (1, 65535)
    WELL_KNOWN = (1, 1023)
    EPHEMERAL = (49152, 65535)
    REGISTERED = (1024, 49151)


class Gender(Enum):
    """Represents genders.

    Value for a lot of methods which
    takes argument ``gender``.
    """

    FEMALE = 'female'
    MALE = 'male'


class TitleType(Enum):
    """Represents title types.

    Value for a method ``Person.title()`` which
    takes parameter``title_type``.
    """

    TYPICAL = 'typical'
    ACADEMIC = 'academic'


class CardType(Enum):
    """Provides cart types.

    Value for a method ``Payment.credit_card_number()`` which
    takes parameter ``card_type``.
    """

    MASTER_CARD = 'MasterCard'
    VISA = 'Visa'
    AMERICAN_EXPRESS = 'American Express'


class Algorithm(Enum):
    """Provides algorithms which available.

    Value for methods which take argument ``algorithm``.
    """

    MD5 = 'md5'
    SHA1 = 'sha1'
    SHA224 = 'sha224'
    SHA256 = 'sha256'
    SHA384 = 'sha384'
    SHA512 = 'sha512'


class TLDType(Enum):
    """Provides top level domain types.

    Value for a method ``Internet.top_level_domain()``
    which takes parameter ``tld_type``.
    """

    CCTLD = 'cctld'
    GTLD = 'gtld'
    GEOTLD = 'geotld'
    UTLD = 'utld'
    STLD = 'stld'


class Layer(Enum):
    """Provides network protocol layers.

    Value for method ``Internet.network_protocol()`` which
    takes parameter ``layer``.
    """

    APPLICATION = 'application'
    DATA_LINK = 'data_link'
    NETWORK = 'network'
    PHYSICAL = 'physical'
    PRESENTATION = 'presentation'
    SESSION = 'session'
    TRANSPORT = 'transport'


class FileType(Enum):
    """Provides file types.

    Value for methods which takes parameter ``file_type``.
    """

    SOURCE = 'source'
    TEXT = 'text'
    DATA = 'data'
    AUDIO = 'audio'
    VIDEO = 'video'
    IMAGE = 'image'
    EXECUTABLE = 'executable'
    COMPRESSED = 'compressed'


class MimeType(Enum):
    """Provides common mime types.

    Value for method ``File.mime_type()`` which
    takes parameter ``type_``.
    """

    APPLICATION = 'application'
    AUDIO = 'audio'
    IMAGE = 'image'
    MESSAGE = 'message'
    TEXT = 'text'
    VIDEO = 'video'


class PrefixSign(Enum):
    """Provides prefix signs.

    Value for method ``UnitSystem.prefix()`` which
    takes parameter ``sign``.
    """

    POSITIVE = 'positive'
    NEGATIVE = 'negative'


class CountryCode(Enum):
    """Provides types of country codes.

    Value for method ``Address.country_code()`` which
    takes parameter ``fmt``.
    """

    A2 = 'a2'
    A3 = 'a3'
    NUMERIC = 'numeric'
    IOC = 'ioc'
    FIFA = 'fifa'


class ISBNFormat(Enum):
    """Provides formats of ISBN.

    Value for method ``Code.isbn()`` which
    takes parameter ``fmt``.
    """

    ISBN13 = 'isbn-13'
    ISBN10 = 'isbn-10'


class EANFormat(Enum):
    """Provides formats of EAN.

    Value for method ``Code.ean()`` which
    takes parameter ``fmt``.
    """

    EAN8 = 'ean-8'
    EAN13 = 'ean-13'


class SocialNetwork(Enum):
    """Provides most popular social networks.

    Value for method ``Person.social_media_profile()`` which
    takes parameter ``site``.
    """

    FACEBOOK = 'facebook'
    TWITTER = 'twitter'
    INSTAGRAM = 'instagram'
    VK = 'vk'


class UnitName(Enum):
    """Provide unit names.

    Value for method ``UnitSystem.unit()`` which
    takes parameter ``name``.
    """

    MASS = ('gram', 'gr')
    INFORMATION = ('byte', 'b')
    THERMODYNAMIC_TEMPERATURE = ('kelvin', 'K')
    AMOUNT_OF_SUBSTANCE = ('mole', 'mol')
    ANGLE = ('radian', 'r')
    SOLID_ANGLE = ('steradian', '㏛')
    FREQUENCY = ('hertz', 'Hz')
    FORCE = ('newton', 'N')
    PRESSURE = ('pascal', 'P')
    ENERGY = ('joule', 'J')
    POWER = ('watt', 'W')
    FLUX = ('watt', 'W')
    ELECTRIC_CHARGE = ('coulomb', 'C')
    VOLTAGE = ('volt', 'V')
    ELECTRIC_CAPACITANCE = ('farad', 'F')
    ELECTRIC_RESISTANCE = ('ohm', 'Ω')
    ELECTRICAL_CONDUCTANCE = ('siemens', 'S')
    MAGNETIC_FLUX = ('weber', 'Wb')
    MAGNETIC_FLUX_DENSITY = ('tesla', 'T')
    INDUCTANCE = ('henry', 'H')
    TEMPERATURE = ('Celsius', '°C')
    RADIOACTIVITY = ('becquerel', 'Bq')



"""Address data provider."""

from typing import Optional, Union

from mimesis.data import (CALLING_CODES, CONTINENT_CODES, COUNTRY_CODES,
                          SHORTENED_ADDRESS_FMT)
from mimesis.enums import CountryCode
from mimesis.providers.base import BaseDataProvider
from mimesis.utils import pull

__all__ = ['Address']


class Address(BaseDataProvider):
    """Class for generate fake address data."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes.

        :param locale: Current locale.
        """
        super().__init__(*args, **kwargs)
        self._data = pull('address.json', self.locale)

    def street_number(self, maximum: int = 1400) -> str:
        """Generate a random street number.

        :param maximum: Maximum value.
        :return: Street number.

        :Example:
            134.
        """
        return str(self.random.randint(1, maximum))

    def street_name(self) -> str:
        """Get a random street name.

        :return: Street name.

        :Example:
           Candlewood.
        """
        return self.random.choice(
            self._data['street']['name'])

    def street_suffix(self) -> str:
        """Get a random street suffix.

        :return: Street suffix.

        :Example:
            Alley.
        """
        return self.random.choice(
            self._data['street']['suffix'])

    def address(self) -> str:
        """Generate a random full address.

        :return: Full address.

        :Example:
            5 Central Sideline.
        """
        fmt = self._data['address_fmt']

        st_num = self.street_number()
        st_name = self.street_name()

        if self.locale in SHORTENED_ADDRESS_FMT:
            return fmt.format(
                st_num=st_num,
                st_name=st_name,
            )

        if self.locale == 'ja':
            return fmt.format(
                self.random.choice(self._data['city']),
                # Generate list of random integers
                # in amount of 3, from 1 to 100.
                *self.random.randints(3, 1, 100),
            )

        return fmt.format(
            st_num=st_num,
            st_name=st_name,
            st_sfx=self.street_suffix(),

        )

    def state(self, abbr: bool = False) -> str:
        """Get a random administrative district of country.

        :param abbr: Return ISO 3166-2 code.
        :return: Administrative district.

        :Example:
            Alabama.
        """
        return self.random.choice(
            self._data['state']['abbr' if abbr else 'name'])

    def region(self, *args, **kwargs) -> str:
        """Get a random region.

        :param bool abbr: Return ISO 3166-2 code.
        :return: State.
        """
        return self.state(*args, **kwargs)

    def province(self, *args, **kwargs) -> str:
        """Get a random province.

        :param args: Arguments.
        :param kwargs: Keyword arguments.
        :return: Province.
        """
        return self.state(*args, **kwargs)

    def federal_subject(self, *args, **kwargs) -> str:
        """Get a random region.

        :param args: Arguments.
        :param kwargs: Keyword arguments.
        :return: Federal subject.
        """
        return self.state(*args, **kwargs)

    def prefecture(self, *args, **kwargs) -> str:
        """Get a random prefecture.

        :param args: Arguments.
        :param kwargs: Keyword arguments.
        :return: Prefecture.
        """
        return self.state(*args, **kwargs)

    def postal_code(self) -> str:
        """Generate a postal code for current locale.

        :return: Postal code.

        :Example:
            389213
        """
        return self.random.custom_code(
            self._data['postal_code_fmt'])

    def zip_code(self) -> str:
        """Generate a zip code.

        An alias for method self.postal_code.

        :return: Zip code.
        """
        return self.postal_code()

    def country_code(self, fmt: Optional[CountryCode] = CountryCode.A2) -> str:
        """Get a random code of country.

        Default format (``fmt``) is ISO 3166-1-alpha2 (``CountryCode.A2``),
        you can change it by passing parameter ``fmt``
        with enum object ``CountryCode``.

        :param fmt: Enum object CountryCode.
        :return: Country code in selected format.
        :raises KeyError: if fmt is not supported.

        :Example:
            DE
        """
        key = self._validate_enum(fmt, CountryCode)
        return self.random.choice(COUNTRY_CODES[key])

    def country(self) -> str:
        """Get a random country.

        :return: The Country.

        :Example:
            Russia.
        """
        return self.random.choice(
            self._data['country']['name'])

    def city(self) -> str:
        """Get a random city.

        :return: City name.

        :Example:
            Saint Petersburg.
        """
        return self.random.choice(
            self._data['city'])

    def _get_fs(self, key: str, dms: bool = False) -> Union[str, float]:
        """Get float number.

        :param key: Key (`lt` or `lg`).
        :param dms: DMS format.
        :return: Float number
        """
        # Default range is a range of longitude.
        rng = (-90, 90) if key == 'lt' else (-180, 180)
        result = self.random.uniform(*rng, precision=6)

        if dms:
            return dd_to_dms(result, key)

        return result

    def latitude(self, dms: bool = False) -> Union[str, float]:
        """Generate a random value of latitude.

        :param dms: DMS format.
        :return: Value of longitude.

        :Example:
            -66.421418
        """
        return self._get_fs('lt', dms)

    def longitude(self, dms: bool = False) -> Union[str, float]:
        """Generate a random value of longitude.

        :param dms: DMS format.
        :return: Value of longitude.

        :Example:
            112.184402
        """
        return self._get_fs('lg', dms)

    def coordinates(self, dms: bool = False) -> dict:
        """Generate random geo coordinates.

        :param dms: DMS format.
        :return: Dict with coordinates.

        :Example:
            {'latitude': 8.003968,
            'longitude': 36.028111}
        """
        return {
            'longitude': self._get_fs('lg', dms),
            'latitude': self._get_fs('lt', dms),
        }

    def continent(self, code: bool = False) -> str:
        """Get a random continent name or continent code.

        :param code: Return code of continent.
        :return: Continent name.

        :Example:
            Africa (en)
        """
        codes = CONTINENT_CODES if \
            code else self._data['continent']

        return self.random.choice(codes)

    def calling_code(self) -> str:
        """Get a random calling code of random country.

        :return: Calling code.

        :Example:
            +7
        """
        return self.random.choice(CALLING_CODES)


# ==========================================#
# INTERNAL FUNCTIONS OF PROVIDER <ADDRESS>  #
# ==========================================#

def dd_to_dms(num: float, _type: str) -> str:
    """Convert decimal number to DMS format.

    :param num: Decimal number.
    :param _type: Type of number.
    :return: Number in DMS format.
    """
    degrees = int(num)
    minutes = int((num - degrees) * 60)
    seconds = (num - degrees - minutes / 60) * 3600.00
    seconds = round(seconds, 3)
    result = [abs(i) for i in (degrees, minutes, seconds)]

    direction = ''
    if _type == 'lg':
        direction = 'W' if degrees < 0 else 'E'
    elif _type == 'lt':
        direction = 'S' if degrees < 0 else 'N'

    return ('{}º{}\'{:.3f}"' + direction).format(*result)



"""Provider of data related to date and time."""

from calendar import monthrange, timegm
from datetime import date, datetime, time

from mimesis.data import GMT_OFFSETS, ROMAN_NUMS, TIMEZONES
from mimesis.providers.base import BaseDataProvider
from mimesis.typing import DateTime, Timestamp
from mimesis.utils import pull

__all__ = ['Datetime']


class Datetime(BaseDataProvider):
    """Class for generating data related to the date and time."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes.

        :param locale: Current locale.
        """
        super().__init__(*args, **kwargs)
        self._data = pull('datetime.json', self.locale)

    def week_date(self, start: int = 2017, end: int = 2018) -> str:
        """Get week number with year.

        :param start: From start.
        :param end: To end.
        :return: Week number.

        :Example:
            2017-W32
        """
        year = self.year(start, end)
        week = self.random.randint(1, 52)
        return '{year}-W{week}'.format(
            year=year,
            week=week,
        )

    def day_of_week(self, abbr: bool = False) -> str:
        """Get a random day of week.

        :param abbr: Abbreviated day name.
        :return: Day of the week.

        :Example:
            Wednesday
        """
        key = 'abbr' if abbr else 'name'
        days = self._data['day'].get(key)
        return self.random.choice(days)

    def month(self, abbr: bool = False) -> str:
        """Get a random month.

        :param abbr: Abbreviated month name.
        :return: Month name.

        :Example:
            January
        """
        key = 'abbr' if abbr else 'name'
        months = self._data['month'].get(key)
        return self.random.choice(months)

    def year(self, minimum: int = 1990,
             maximum: int = 2050) -> int:
        """Generate a random year.

        :param minimum: Minimum value.
        :param maximum: Maximum value.
        :return: Year.

        :Example:
            2023
        """
        return self.random.randint(minimum, maximum)

    def century(self) -> str:
        """Get a random century.

        :return: Century.

        :Example:
            XXI
        """
        return self.random.choice(ROMAN_NUMS)

    def periodicity(self) -> str:
        """Get a random periodicity string.

        :return: Periodicity.

        :Example:
            Never.
        """
        periodicity = self._data['periodicity']
        return self.random.choice(periodicity)

    def date(self, start: int = 2000,
             end: int = 2035, fmt: str = '') -> str:
        """Generate a string representing of random date.

        Date can be automatically formatted for the current
        locale or specified.

        :param start: Minimum value of year.
        :param end: Maximum value of year.
        :param fmt: Format string for date.
        :return: Formatted date.

        :Example:
            08/16/88 (en)
        """
        if not fmt:
            fmt = self._data['formats'].get('date')

        year = self.random.randint(start, end)
        month = self.random.randint(1, 12)
        d = date(year, month, self.random.randint(
            1, monthrange(year, month)[1]))
        return d.strftime(fmt)

    def time(self, fmt: str = '') -> str:
        """Generate a random time.

        Time can be automatically formatted for the current
        locale or specified.

        :param fmt: Format of time.
        :return: Time.

        :Example:
            21:30:00
        """
        if not fmt:
            fmt = self._data['formats'].get('time')

        t = time(
            self.random.randint(0, 23),
            self.random.randint(0, 59),
            self.random.randint(0, 59),
            self.random.randint(0, 999999),
        )
        return t.strftime(fmt)

    def day_of_month(self) -> int:
        """Generate a random day of month, from 1 to 31.

        :return: Random value from 1 to 31.

        :Example:
            23
        """
        return self.random.randint(1, 31)

    def timezone(self) -> str:
        """Get a random timezone.

        :return: Timezone.

        :Example:
            Europe/Paris
        """
        return self.random.choice(TIMEZONES)

    def gmt_offset(self) -> str:
        """Get a random GMT offset value.

        :return: GMT Offset.

        :Example:
            'UTC +03:00'
        """
        return self.random.choice(GMT_OFFSETS)

    def datetime(self, humanized: bool = False, **kwargs) -> DateTime:
        """Generate random datetime.

        :param humanized: Readable representation.
        :param kwargs: Keyword arguments (start, end).
        :return: Datetime.
        :rtype: datetime.datetime

        :Example:
            March, 24 2002
        """
        fmt = '%Y-%m-%d %H:%M:%S'
        dt_str = '{date} {time}'.format(
            date=self.date(fmt='%Y-%m-%d', **kwargs),
            time=self.time(),
        )

        dt = datetime.strptime(dt_str, fmt)

        if humanized:
            return dt.strftime('%B, %d %Y')

        return dt

    def timestamp(self, posix: bool = True, **kwargs) -> Timestamp:
        """Generate random timestamp.

        :param posix: POSIX time.
        :param kwargs: Keyword arguments (start, end).
        :return: Timestamp.
        :rtype: str or int

        :Example:
            2018-01-02T06:19:19Z
        """
        stamp = self.datetime(**kwargs)

        if posix:
            return timegm(stamp.utctimetuple())

        return stamp.strftime('%Y-%m-%dT%H:%M:%SZ')



"""Contains all the available data providers."""

from mimesis.providers.base import BaseProvider, BaseDataProvider
from mimesis.providers.address import Address
from mimesis.providers.business import Business
from mimesis.providers.clothing import ClothingSize
from mimesis.providers.cryptographic import Cryptographic
from mimesis.providers.code import Code
from mimesis.providers.date import Datetime
from mimesis.providers.development import Development
from mimesis.providers.file import File
from mimesis.providers.food import Food
from mimesis.providers.hardware import Hardware
from mimesis.providers.internet import Internet
from mimesis.providers.numbers import Numbers
from mimesis.providers.path import Path
from mimesis.providers.person import Person
from mimesis.providers.payment import Payment
from mimesis.providers.science import Science
from mimesis.providers.structure import Structure
from mimesis.providers.text import Text
from mimesis.providers.transport import Transport
from mimesis.providers.units import UnitSystem
from mimesis.providers.games import Games
from mimesis.providers.generic import Generic

__all__ = [
    # The main class:
    'BaseProvider',

    # Data base class:
    'BaseDataProvider',

    # And data providers:
    'Address',
    'Business',
    'ClothingSize',
    'Code',
    'Datetime',
    'Development',
    'File',
    'Food',
    'Games',
    'Hardware',
    'Internet',
    'Numbers',
    'Path',
    'Payment',
    'Person',
    'Science',
    'Structure',
    'Text',
    'Transport',
    'UnitSystem',
    'Cryptographic',

    # Has all:
    'Generic',
]



"""Configuration file."""

SUPPORTED_LOCALES = {
    'cs': {
        'name': 'Czech',
        'name_local': 'česky',
    },
    'da': {
        'name': 'Danish',
        'name_local': 'Dansk',
    },
    'de': {
        'name': 'German',
        'name_local': 'Deutsch',
    },
    'de-at': {
        'name': 'Austrian German',
        'name_local': 'Deutsch',
    },
    'de-ch': {
        'name': 'Swiss German',
        'name_local': 'Deutsch',
    },
    'el': {
        'name': 'Greek',
        'name_local': 'Ελληνικά',
    },
    'en': {
        'name': 'English',
        'name_local': 'English',
    },
    'en-gb': {
        'name': 'British English',
        'name_local': 'English',
    },
    'en-au': {
        'name': 'Australian English',
        'name_local': 'English',
    },
    'en-ca': {
        'name': 'Canadian English',
        'name_local': 'English',
    },
    'es': {
        'name': 'Spanish',
        'name_local': 'Español',
    },
    'es-mx': {
        'name': 'Mexican Spanish',
        'name_local': 'Español',
    },
    'et': {
        'name': 'Estonian',
        'name_local': 'Eesti',
    },
    'fa': {
        'name': 'Farsi',
        'name_local': 'فارسی',
    },
    'fi': {
        'name': 'Finnish',
        'name_local': 'Suomi',
    },
    'fr': {
        'name': 'French',
        'name_local': 'Français',
    },
    'hu': {
        'name': 'Hungarian',
        'name_local': 'Magyar',
    },
    'is': {
        'name': 'Icelandic',
        'name_local': 'Íslenska',
    },
    'it': {
        'name': 'Italian',
        'name_local': 'Italiano',
    },
    'ja': {
        'name': 'Japanese',
        'name_local': '日本語',
    },
    'kk': {
        'name': 'Kazakh',
        'name_local': 'Қазақша',
    },
    'ko': {
        'name': 'Korean',
        'name_local': '한국어',
    },
    'nl': {
        'name': 'Dutch',
        'name_local': 'Nederlands',
    },
    'nl-be': {
        'name': 'Belgium Dutch',
        'name_local': 'Nederlands',
    },
    'no': {
        'name': 'Norwegian',
        'name_local': 'Norsk',
    },
    'pl': {
        'name': 'Polish',
        'name_local': 'Polski',
    },
    'pt': {
        'name': 'Portuguese',
        'name_local': 'Português',
    },
    'pt-br': {
        'name': 'Brazilian Portuguese',
        'name_local': 'Português Brasileiro',
    },
    'ru': {
        'name': 'Russian',
        'name_local': 'Русский',
    },
    'sv': {
        'name': 'Swedish',
        'name_local': 'Svenska',
    },
    'tr': {
        'name': 'Turkish',
        'name_local': 'Türkçe',
    },
    'uk': {
        'name': 'Ukrainian',
        'name_local': 'Українська',
    },
    'zh': {
        'name': 'Chinese',
        'name_local': '汉语',
    },
}

# List of all supported locales.
LIST_OF_LOCALES = list(SUPPORTED_LOCALES)

# Default locale.
DEFAULT_LOCALE = 'en'



"""Provides pseudo-scientific data."""

from typing import Union

from mimesis.data import MATH_FORMULAS
from mimesis.providers.base import BaseDataProvider
from mimesis.utils import pull

__all__ = ['Science']


class Science(BaseDataProvider):
    """Class for generating pseudo-scientific data."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes.

        :param locale: Current language.
        :param seed: Seed.
        """
        super().__init__(*args, **kwargs)
        self._data = pull('science.json', self.locale)

    def math_formula(self) -> str:
        """Get a random mathematical formula.

        :return: Math formula.

        :Example:
            A = (ab)/2.
        """
        formula = self.random.choice(MATH_FORMULAS)
        return formula

    def chemical_element(self, name_only: bool = True) -> Union[dict, str]:
        """Generate a random chemical element.

        :param name_only: If False then will be returned dict.
        :return: Name of chemical element or dict.
        :rtype: dict or str

        :Example:
            {'Symbol': 'S', 'Name': 'Sulfur', 'Atomic number': '16'}
        """
        elements = self._data['chemical_element']
        nm, sm, an = self.random.choice(elements).split('|')

        if not name_only:
            return {
                'name': nm.strip(),
                'symbol': sm.strip(),
                'atomic_number': an.strip(),
            }

        return nm.strip()

    def atomic_number(self) -> int:
        """Generate random atomic number.

        :return: Atomic number

        :Example:
            92
        """
        return self.random.randint(1, 119)

    def scientific_article(self) -> str:
        """Generate a random link to scientific article on Wikipedia.

        :return: Link to the article.

        :Example:
            https://en.wikipedia.org/wiki/Black_hole
        """
        articles = self._data['article']
        return self.random.choice(articles)

    def rna(self, length: int = 10) -> str:
        """Generate a random RNA sequence.

        :param length: Length of block.
        :return: RNA sequence.

        :Example:
            AGUGACACAA
        """
        return self.random.schoice('UCGA', length)

    def dna(self, length: int = 10) -> str:
        """Generate a random DNA sequence.

        :param length: Length of block.
        :return: DNA sequence.

        :Example:
            GCTTTAGACC
        """
        return self.random.schoice('TCGA', length)



"""Provides data related to paths."""

import sys
from typing import Union

from mimesis.data import (FOLDERS, PLATFORMS, PROGRAMMING_LANGS, PROJECT_NAMES,
                          USERNAMES)
from mimesis.providers.base import BaseDataProvider

__all__ = ['Path']


class Path(BaseDataProvider):
    """Class that provides methods and property for generate paths."""

    def __init__(self, platform: str = sys.platform, *args, **kwargs) -> None:
        """Initialize attributes.

        Supported platforms: 'linux', 'darwin', 'win32', 'win64'.

        :param platform: Required platform type.
        """
        super().__init__(*args, **kwargs)
        self.platform = platform

    def root(self) -> Union[str, None]:
        """Generate a root dir path.

        :return: Root dir.

        :Example:
            /
        """
        for platform in PLATFORMS:
            if self.platform == PLATFORMS[platform]['name']:
                root = PLATFORMS[platform]['root']
                return root

    def home(self) -> Union[str, None]:
        """Generate a home path.

        :return: Home path.

        :Example:
            /home/
        """
        for platform in PLATFORMS:
            if self.platform == PLATFORMS[platform]['name']:
                home = PLATFORMS[platform]['home']
                return home

    def user(self) -> Union[str, None]:
        """Generate a random user.

        :return: Path to user.

        :Example:
            /home/oretha
        """
        user = self.random.choice(USERNAMES)
        user = user.capitalize() if \
            self.platform == 'win32' else user.lower()
        return '{}{}'.format(self.home(), user)

    def users_folder(self) -> Union[str, None]:
        """Generate a random path to user's folders.

        :return: Path.

        :Example:
            /home/taneka/Pictures
        """
        folder = self.random.choice(FOLDERS)
        user = self.user()
        for platform in PLATFORMS:
            if self.platform == PLATFORMS[platform]['name']:
                sep = PLATFORMS[platform]['path_separator']
                return '{user}{sep}{folder}'.format(
                    user=user,
                    sep=sep,
                    folder=folder,
                )

    def dev_dir(self) -> Union[str, None]:
        """Generate a random path to development directory.

        :return: Path.

        :Example:
            /home/sherrell/Development/Python/mercenary
        """
        folder = self.random.choice(['Development', 'Dev'])
        stack = self.random.choice(PROGRAMMING_LANGS)
        for platform in PLATFORMS:
            if self.platform == PLATFORMS[platform]['name']:
                sep = PLATFORMS[platform]['path_separator']
                return '{user}{sep}{folder}{sep}{stack}'.format(
                    user=self.user(),
                    sep=sep,
                    folder=folder,
                    stack=stack,
                )

    def project_dir(self) -> Union[str, None]:
        """Generate a random path to project directory.

        :return: Path to project.

        :Example:
            /home/sherika/Development/Falcon/mercenary
        """
        project = self.random.choice(PROJECT_NAMES)
        dev_dir = self.dev_dir()
        for platform in PLATFORMS:
            if self.platform == PLATFORMS[platform]['name']:
                sep = PLATFORMS[platform]['path_separator']

                return '{dev_dir}{sep}{project}'.format(
                    dev_dir=dev_dir,
                    sep=sep,
                    project=project,
                )



"""Provides personal data."""

import hashlib
from string import ascii_letters, digits, punctuation
from typing import Optional, Union

from mimesis.data import (BLOOD_GROUPS, CALLING_CODES, EMAIL_DOMAINS,
                          ENGLISH_LEVEL, GENDER_SYMBOLS, MUSIC_GENRE,
                          SEXUALITY_SYMBOLS, SOCIAL_NETWORKS, USERNAMES)
from mimesis.enums import Gender, SocialNetwork, TitleType
from mimesis.exceptions import NonEnumerableError
from mimesis.helpers import get_random_item
from mimesis.providers.base import BaseDataProvider
from mimesis.utils import pull

__all__ = ['Person']


class Person(BaseDataProvider):
    """Class for generating personal data."""

    def __init__(self, *args, **kwargs) -> None:
        """Initialize attributes.

        :param locale: Current locale.
        :param seed: Seed.
        """
        super().__init__(*args, **kwargs)
        self._data = pull('person.json', self.locale)
        self._store = {
            'age': 0,
        }

    def age(self, minimum: int = 16, maximum: int = 66) -> int:
        """Get a random integer value.

        :param maximum: Maximum value of age.
        :param minimum: Minimum value of age.
        :return: Random integer.

        :Example:
            23.
        """
        a = self.random.randint(int(minimum), int(maximum))
        self._store['age'] = a
        return a

    def child_count(self, max_children: int = 5) -> int:
        """Get a count of children.

        :param max_children: Maximum count of children.
        :return: Ints. Depend on previous generated age.
        """
        a = self._store['age']
        if a == 0:
            a = self.age()

        cc = 0 if a < 18 else self.random.randint(0, max_children)
        return cc

    def work_experience(self, working_start_age: int = 22) -> int:
        """Get a work experience.

        :param working_start_age: Age then person start to work.
        :return: Depend on previous generated age.
        """
        a = self._store['age']
        if a == 0:
            a = self.age()

        return max(a - working_start_age, 0)

    def name(self, gender: Optional[Gender] = None) -> str:
        """Generate a random name.

        :param gender: Gender's enum object.
        :return: Name.

        :Example:
            John.
        """
        key = self._validate_enum(gender, Gender)
        names = self._data['names'].get(key)
        return self.random.choice(names)

    def surname(self, gender: Optional[Gender] = None) -> str:
        """Generate a random surname.

        :param gender: Gender's enum object.
        :return: Surname.

        :Example:
            Smith.
        """
        surnames = self._data['surnames']

        # Surnames separated by gender.
        if isinstance(surnames, dict):
            key = self._validate_enum(gender, Gender)
            surnames = surnames[key]

        return self.random.choice(surnames)

    def last_name(self, gender: Optional[Gender] = None) -> str:
        """Generate a random last name.

        ..note: An alias for self.surname().

        :param gender: Gender's enum object.
        :return: Last name.
        """
        return self.surname(gender)

    def title(self, gender: Optional[Gender] = None,
              title_type: Optional[TitleType] = None) -> str:
        """Generate a random title for name.

        You can generate random prefix or suffix
        for name using this method.

        :param gender: The gender.
        :param title_type: TitleType enum object.
        :return: The title.
        :raises NonEnumerableError: if gender or title_type in incorrect format.

        :Example:
            PhD.
        """
        gender_key = self._validate_enum(gender, Gender)
        title_key = self._validate_enum(title_type, TitleType)

        titles = self._data['title'][gender_key][title_key]
        return self.random.choice(titles)

    def full_name(self, gender: Optional[Gender] = None,
                  reverse: bool = False) -> str:
        """Generate a random full name.

        :param reverse: Return reversed full name.
        :param gender: Gender's enum object.
        :return: Full name.

        :Example:
            Johann Wolfgang.
        """
        if gender is None:
            gender = get_random_item(Gender, rnd=self.random)

        if gender and isinstance(gender, Gender):
            gender = gender
        else:
            raise NonEnumerableError(Gender)

        fmt = '{1} {0}' if reverse else '{0} {1}'
        return fmt.format(
            self.name(gender),
            self.surname(gender),
        )

    def username(self, template: Optional[str] = None) -> str:
        """Generate username by template.

        Supported templates: ('U_d', 'U.d', 'U-d', 'UU-d', 'UU.d', 'UU_d',
        'ld', 'l-d', 'Ud', 'l.d', 'l_d', 'default')

        :param template: Template
        :return: Username.
        :raises KeyError: if template is not supported.

        :Example:
            Celloid1873
        """
        # TODO: Optimize
        _name = None
        if template in ('UU-d', 'UU.d', 'UU_d'):
            _name = self.random.choice(USERNAMES) \
                .capitalize()

        name = self.random.choice(USERNAMES)
        date = self.random.randint(1800, 2070)

        templates = ('U-d', 'U.d', 'UU-d', 'UU.d', 'UU_d', 'U_d',
                     'Ud', 'l-d', 'l.d', 'l_d', 'ld', 'default')

        if template is None:
            template = self.random.choice(templates)

        if template not in templates:
            raise KeyError(
                'Template «{template}» is not in {templates}'.format(
                    template=template,
                    templates=templates,
                ),
            )
        if template == 'Ud':
            return '{}{}'.format(name.capitalize(), date)
        elif template == 'U.d':
            return '{}.{}'.format(name.capitalize(), date)
        elif template == 'ld':
            return '{}{}'.format(name, date)
        elif template == 'UU.d':
            return '{}{}.{}'.format(name.capitalize(), _name, date)
        elif template == 'UU_d':
            return '{}{}_{}'.format(name.capitalize(), _name, date)
        elif template == 'UU-d':
            return '{}{}-{}'.format(name.capitalize(), _name, date)
        elif template == 'U-d':
            return '{}-{}'.format(name.title(), date)
        elif template == 'U_d':
            return '{}_{}'.format(name.title(), date)
        elif template == 'l-d':
            return '{}-{}'.format(name, date)
        elif template == 'l_d':
            return '{}_{}'.format(name, date)

        return '{}.{}'.format(name, date)

    def password(self, length: int = 8, hashed: bool = False) -> str:
        """Generate a password or hash of password.

        :param length: Length of password.
        :param hashed: MD5 hash.
        :return: Password or hash of password.

        :Example:
            k6dv2odff9#4h
        """
        text = ascii_letters + digits + punctuation
        password = ''.join([self.random.choice(text) for _ in range(length)])

        if hashed:
            md5 = hashlib.md5()
            md5.update(password.encode())
            return md5.hexdigest()
        else:
            return password

    def email(self, domains: Union[tuple, list] = None) -> str:
        """Generate a random email.

        :param domains: List of custom domains for emails.
        :type domains: list or tuple
        :return: Email address.

        :Example:
            foretime10@live.com
        """
        if not domains:
            domains = EMAIL_DOMAINS

        domain = self.random.choice(domains)
        name = self.username(template='ld')
        return '{name}{domain}'.format(
            name=name,
            domain=domain,
        )

    def social_media_profile(self, site: Optional[SocialNetwork] = None) -> str:
        """Generate profile for random social network.

        :return: Profile in some network.

        :Example:
            http://facebook.com/some_user
        """
        key = self._validate_enum(site, SocialNetwork)
        website = SOCIAL_NETWORKS[key]
        url = 'https://www.' + website
        return url.format(self.username())

    def gender(self, iso5218: bool = False,
               symbol: bool = False) -> Union[str, int]:
        """Get a random gender.

        Get a random title of gender, code for the representation
        of human sexes is an international standard that defines a
        representation of human sexes through a language-neutral single-digit
        code or symbol of gender.

        :param iso5218:
            Codes for the representation of human sexes is an international
            standard (0 - not known, 1 - male, 2 - female, 9 - not applicable).
        :param symbol: Symbol of gender.
        :return: Title of gender.

        :Example:
            Male
        """
        if iso5218:
            return self.random.choice([0, 1, 2, 9])

        if symbol:
            return self.random.choice(GENDER_SYMBOLS)

        return self.random.choice(self._data['gender'])

    def height(self, minimum: float = 1.5, maximum: float = 2.0) -> str:
        """Generate a random height in M (Meter).

        :param minimum: Minimum value.
        :param float maximum: Maximum value.
        :return: Height.

        :Example:
            1.85.
        """
        h = self.random.uniform(minimum, maximum)
        return '{:0.2f}'.format(h)

    def weight(self, minimum: int = 38, maximum: int = 90) -> int:
        """Generate a random weight in Kg.

        :param minimum: min value
        :param maximum: max value
        :return: Weight.

        :Example:
            48.
        """
        weight = self.random.randint(minimum, maximum)
        return weight

    def blood_type(self) -> str:
        """Get a random blood type.

        :return: Blood type (blood group).

        :Example:
            A+
        """
        return self.random.choice(BLOOD_GROUPS)

    def sexual_orientation(self, symbol: bool = False) -> str:
        """Get a random (LOL) sexual orientation.

        :param symbol: Unicode symbol.
        :return: Sexual orientation.

        :Example:
            Heterosexuality.
        """
        if symbol:
            return self.random.choice(SEXUALITY_SYMBOLS)

        sexuality = self._data['sexuality']
        return self.random.choice(sexuality)

    def occupation(self) -> str:
        """Get a random job.

        :return: The name of job.

        :Example:
            Programmer.
        """
        jobs = self._data['occupation']
        return self.random.choice(jobs)

    def political_views(self) -> str:
        """Get a random political views.

        :return: Political views.

        :Example:
            Liberal.
        """
        views = self._data['political_views']
        return self.random.choice(views)

    def worldview(self) -> str:
        """Get a random worldview.

        :return: Worldview.

        :Example:
            Pantheism.
        """
        views = self._data['worldview']
        return self.random.choice(views)

    def views_on(self) -> str:
        """Get a random views on.

        :return: Views on.

        :Example:
            Negative.
        """
        views = self._data['views_on']
        return self.random.choice(views)

    def nationality(self, gender: Optional[Gender] = None) -> str:
        """Get a random nationality.

        :param gender: Gender.
        :return: Nationality.

        :Example:
            Russian
        """
        nationalities = self._data['nationality']

        # Separated by gender
        if isinstance(nationalities, dict):
            key = self._validate_enum(gender, Gender)
            nationalities = nationalities[key]

        return self.random.choice(nationalities)

    def university(self) -> str:
        """Get a random university.

        :return: University name.

        :Example:
            MIT.
        """
        universities = self._data['university']
        return self.random.choice(universities)

    def academic_degree(self) -> str:
        """Get a random academic degree.

        :return: Degree.

        :Example:
            Bachelor.
        """
        degrees = self._data['academic_degree']
        return self.random.choice(degrees)

    def language(self) -> str:
        """Get a random language.

        :return: Random language.

        :Example:
            Irish.
        """
        languages = self._data['language']
        return self.random.choice(languages)

    def favorite_movie(self) -> str:
        """Get a random movie for current locale.

        :return: The name of the movie.

        :Example:
            Interstellar.
        """
        movies = self._data['favorite_movie']
        return self.random.choice(movies)

    def favorite_music_genre(self) -> str:
        """Get a random music genre.

        :return: A music genre.

        :Example:
            Ambient.
        """
        return self.random.choice(MUSIC_GENRE)

    def telephone(self, mask: str = '', placeholder: str = '#') -> str:
        """Generate a random phone number.

        :param mask: Mask for formatting number.
        :param placeholder: A placeholder for a mask (default is #).
        :return: Phone number.

        :Example:
            +7-(963)-409-11-22.
        """
        if not mask:
            code = self.random.choice(CALLING_CODES)
            default = '{}-(###)-###-####'.format(code)
            masks = self._data.get('telephone_fmt', [default])
            mask = self.random.choice(masks)

        return self.random.custom_code(mask=mask, digit=placeholder)

    def avatar(self, size: int = 256) -> str:
        """Generate a random avatar..

        :param size: Size of avatar.
        :return: Link to avatar.
        """
        url = 'https://api.adorable.io/avatars/{0}/{1}.png'
        return url.format(size, self.password(hashed=True))

    def identifier(self, mask: str = '##-##/##') -> str:
        """Generate a random identifier by mask.

        With this method you can generate any identifiers that
        you need. Simply select the mask that you need.

        :param mask:
            The mask. Here ``@`` is a placeholder for characters and ``#`` is
            placeholder for digits.
        :return: An identifier.

        :Example:
            07-97/04
        """
        return self.random.custom_code(mask=mask)

    def level_of_english(self) -> str:
        """Get a random level of English.

        :return: Level of english.

        :Example:
            Intermediate.
        """
        return self.random.choice(ENGLISH_LEVEL)



"""Specific data provider for Russia (ru)."""

from typing import Optional

from mimesis.builtins.base import BaseSpecProvider
from mimesis.enums import Gender
from mimesis.utils import pull

__all__ = ['RussiaSpecProvider']


class RussiaSpecProvider(BaseSpecProvider):
    """Class that provides special data for Russia (ru)."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes."""
        super().__init__(*args, **kwargs)
        self._data = pull('builtin.json', 'ru')

    class Meta:
        """The name of the provider."""

        name = 'russia_provider'

    def generate_sentence(self) -> str:
        """Generate sentence from the parts.

        :return: Sentence.
        """
        sentences = self._data['sentence']
        sentence = [
            self.random.choice(sentences[k]) for k
            in ('head', 'p1', 'p2', 'tail')
        ]
        return '{0} {1} {2} {3}'.format(*sentence)

    def patronymic(self, gender: Optional[Gender] = None) -> str:
        """Generate random patronymic name.

        :param gender: Gender of person.
        :return: Patronymic name.

        :Example:
            Алексеевна.
        """
        gender = self._validate_enum(gender, Gender)
        patronymics = self._data['patronymic'][gender]
        return self.random.choice(patronymics)

    def passport_series(self, year: int = None) -> str:
        """Generate random series of passport.

        :param year: Year of manufacture.
        :type year: int or None
        :return: Series.

        :Example:
            02 15.
        """
        if not year:
            year = self.random.randint(10, 18)

        region = self.random.randint(1, 99)
        return '{:02d} {}'.format(region, year)

    def passport_number(self) -> int:
        """Generate random passport number.

        :return: Number.

        :Example:
            560430
        """
        return self.random.randint(
            100000, 999999)

    def series_and_number(self) -> str:
        """Generate a random passport number and series.

        :return: Series and number.

        :Example:
            57 16 805199.
        """
        return '{}{}'.format(
            self.passport_series(),
            self.passport_number(),
        )

    def snils(self) -> str:
        """Generate invalid ``SNILS``.

        This method does not generate SNILS using algorithm and
        it's mean that SNILS generated by this method can be invalid.

        :return: SNILS.

        :Example:
            451-952-540-41.
        """
        mask = '###-###-###-##'
        return self.random.custom_code(mask=mask)

    def inn(self) -> str:
        """Generate random, but valid ``INN``.

        :return: INN.
        """
        def control_sum(nums: list, t: str) -> int:
            digits = {
                'n2': [7, 2, 4, 10, 3, 5, 9, 4, 6, 8],
                'n1': [3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8],
            }
            number = 0
            length = digits[t]
            for i in range(0, len(length)):
                number += nums[i] * length[i]
            return number % 11 % 10

        numbers = []
        for x in range(0, 10):
            numbers.append(self.random.randint(1 if x == 0 else 0, 9))

        n2 = control_sum(numbers, 'n2')
        numbers.append(n2)
        n1 = control_sum(numbers, 'n1')
        numbers.append(n1)
        return ''.join([str(x) for x in numbers])

    def ogrn(self) -> str:
        """Generate random valid ``OGRN``.

        :return: OGRN.

        :Example:
            4715113303725.
        """
        numbers = []
        for _ in range(0, 12):
            numbers.append(self.random.randint(1 if _ == 0 else 0, 9))

        ogrn = ''.join([str(x) for x in numbers])
        check_sum = str(int(ogrn) % 11 % 10)

        return '{}{}'.format(ogrn, check_sum)

    def bic(self) -> str:
        """Generate random ``BIC`` (Bank ID Code).

        :return: BIC.

        :Example:
            044025575.
        """
        country_code = '04'
        code = '{:02}'.format(self.random.randint(1, 10))
        bank_number = '{:02}'.format(self.random.randint(0, 99))
        bank_office = '{:03}'.format(self.random.randint(50, 999))
        bic = country_code + code + bank_number + bank_office
        return bic



"""The data provider of a variety of codes."""

from typing import Optional

from mimesis.data import (EAN_MASKS, IMEI_TACS, ISBN_GROUPS, ISBN_MASKS,
                          LOCALE_CODES)
from mimesis.enums import EANFormat, ISBNFormat
from mimesis.providers.base import BaseDataProvider
from mimesis.utils import luhn_checksum

__all__ = ['Code']


class Code(BaseDataProvider):
    """Class that provides methods for generating codes."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes.

        :param locale: Current locale.
        """
        super().__init__(*args, **kwargs)

    def locale_code(self) -> str:
        """Get a random locale code (MS-LCID).

        See Windows Language Code Identifier Reference
        for more information.

        :return: Locale code.

        :Example:
            de-ch
        """
        return self.random.choice(LOCALE_CODES)

    def issn(self, mask: str = '####-####') -> str:
        """Generate a random ISSN.

        :param mask: Mask of ISSN.
        :return: ISSN.
        """
        return self.random.custom_code(mask=mask)

    def isbn(self, fmt: Optional[ISBNFormat] = None) -> str:
        """Generate ISBN for current locale.

        Default ``fmt`` is ISBN 10, but you also can use ISBN-13.

        :param fmt: ISBN format.
        :return: ISBN.
        :raises NonEnumerableError: if fmt is not enum ISBNFormat.

        :Example:
            132-1-15411-375-8.
        """
        fmt_value = self._validate_enum(item=fmt, enum=ISBNFormat)
        mask = ISBN_MASKS[fmt_value].format(
            ISBN_GROUPS[self.locale])
        return self.random.custom_code(mask)

    def ean(self, fmt: Optional[EANFormat] = None) -> str:
        """Generate EAN.

        Default ``fmt`` is EAN-13, but you also can use EAN-8.

        :param fmt: Format of EAN.
        :return: EAN.
        :raises NonEnumerableError: if fmt is not enum EANFormat.

        :Example:
            3953753179567.
        """
        key = self._validate_enum(
            item=fmt,
            enum=EANFormat,
        )
        mask = EAN_MASKS[key]
        return self.random.custom_code(mask=mask)

    def imei(self) -> str:
        """Generate a random IMEI.

        :return: IMEI.

        :Example:
            353918052107063
        """
        num = self.random.choice(IMEI_TACS)
        num = num + str(self.random.randint(100000, 999999))
        return num + luhn_checksum(num)

    def pin(self, mask: str = '####') -> str:
        """Generate a random PIN code.

        :param mask: Mask of pin code.
        :return: PIN code.

        :Example:
            5241.
        """
        return self.random.custom_code(mask=mask)



"""Provides data related to internet."""

from ipaddress import IPv6Address
from typing import Optional, Union

from mimesis.data import (EMOJI, HASHTAGS, HTTP_METHODS, HTTP_STATUS_CODES,
                          HTTP_STATUS_MSGS, NETWORK_PROTOCOLS, SUBREDDITS,
                          SUBREDDITS_NSFW, TLD, TORRENT_CATEGORIES,
                          USER_AGENTS, USERNAMES)
from mimesis.enums import Layer, MimeType, PortRange, TLDType
from mimesis.exceptions import NonEnumerableError
from mimesis.providers.base import BaseDataProvider
from mimesis.providers.file import File
from mimesis.typing import Size

__all__ = ['Internet']


class Internet(BaseDataProvider):
    """Class for generating data related to the internet."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes.

        :param args: Arguments.
        :param kwargs: Keyword arguments.
        """
        super().__init__(*args, **kwargs)
        self.__file = File('en', seed=self.seed)

    def content_type(self, mime_type: Optional[MimeType] = None) -> str:
        """Get a random HTTP content type.

        :return: Content type.

        :Example:
            Content-Type: application/json
        """
        fmt = self.__file.mime_type(type_=mime_type)
        return 'Content-Type: {}'.format(fmt)

    def http_status_message(self) -> str:
        """Get a random HTTP status message.

        :return: HTTP status message.

        :Example:
            200 OK
        """
        return self.random.choice(HTTP_STATUS_MSGS)

    def http_status_code(self) -> int:
        """Get a random HTTP status code.

        :return: HTTP status.

        :Example:
            200
        """
        return self.random.choice(HTTP_STATUS_CODES)

    def http_method(self) -> str:
        """Get a random HTTP method.

        :return: HTTP method.

        :Example:
            POST
        """
        return self.random.choice(HTTP_METHODS)

    def ip_v4(self, with_port: bool = False) -> str:
        """Generate a random IPv4 address.

        :param with_port: Add port to IP.
        :return: Random IPv4 address.

        :Example:
            19.121.223.58
        """
        ip = '.'.join(str(self.random.randint(0, 255)) for _ in range(4))

        if with_port:
            ip += ':{}'.format(self.port())

        return ip

    def ip_v6(self) -> str:
        """Generate a random IPv6 address.

        :return: Random IPv6 address.

        :Example:
            2001:c244:cf9d:1fb1:c56d:f52c:8a04:94f3
        """
        ipv6 = IPv6Address(
            self.random.randint(
                0, 2 ** 128 - 1,
            ),
        )
        return str(ipv6)

    def mac_address(self) -> str:
        """Generate a random MAC address.

        :return: Random MAC address.

        :Example:
            00:16:3e:25:e7:b1
        """
        mac_hex = [
            0x00, 0x16, 0x3e,
            self.random.randint(0x00, 0x7f),
            self.random.randint(0x00, 0xff),
            self.random.randint(0x00, 0xff),
        ]
        mac = map(lambda x: '%02x' % x, mac_hex)
        return ':'.join(mac)

    def emoji(self) -> str:
        """Get a random emoji shortcut code.

        :return: Emoji code.

        :Example:
            :kissing:
        """
        return self.random.choice(EMOJI)

    def image_placeholder(self, width: Optional[Size] = None,
                          height: Optional[Size] = None) -> str:
        """Generate a link to the image placeholder.

        :param width: Width of image.
        :type width: str or int
        :param height: Height of image.
        :type height: str or int
        :return: URL to image placeholder.
        """
        url = 'http://placehold.it/{width}x{height}'
        if not width:
            width = self.random.randint(16, 1024)

        if not height:
            height = self.random.randint(16, int(width))

        return url.format(width=width, height=height)

    def stock_image(self, category: str = '',
                    width: Size = 1900, height: Size = 1080) -> str:
        """Generate random stock image hosted on Unsplash.

        :param category: Category of images.
        :param width: Width of the image.
        :type width: str or int
        :param height: Height of the image.
        :type height: str or int
        :return: An image (Link to image).
        """
        url = 'https://source.unsplash.com/category/' \
              '{category}/{width}x{height}'

        if not category:
            categories = [
                'buildings', 'food', 'nature',
                'people', 'technology', 'objects',
            ]
            category = self.random.choice(categories)

        return url.format(category=category, width=width, height=height)

    def image_by_keyword(self, keyword: str = '') -> str:
        """Generate image by keyword.

        :param keyword: Keyword.
        :return: Link to image.
        """
        url = 'https://source.unsplash.com/weekly?{keyword}'

        if not keyword:
            keywords = [
                'cat', 'girl', 'boy', 'beauty',
                'nature', 'woman', 'man', 'tech',
                'space',
            ]
            keyword = self.random.choice(keywords)

        return url.format(keyword=keyword)

    def hashtags(self, quantity: int = 4) -> Union[str, list]:
        """Generate a list of hashtags.

        :param quantity: The quantity of hashtags.
        :return: The list of hashtags.
        :rtype: str or list
        :raises NonEnumerableError: if category is not in Hashtag.

        :Example:
            ['#love', '#sky', '#nice']
        """
        tags = ['#' + self.random.choice(HASHTAGS)
                for _ in range(quantity)]

        if int(quantity) == 1:
            return tags[0]

        return tags

    def home_page(self, tld_type: Optional[TLDType] = None) -> str:
        """Generate a random home page.

        :param tld_type: TLD type.
        :return: Random home page.

        :Example:
            http://www.fontir.info
        """
        resource = self.random.choice(USERNAMES)
        domain = self.top_level_domain(
            tld_type=tld_type,
        )

        return 'http://www.{}{}'.format(
            resource, domain)

    def top_level_domain(self, tld_type: Optional[TLDType] = None) -> str:
        """Return random top level domain.

        :param tld_type: Enum object DomainType
        :return: Top level domain.
        :raises NonEnumerableError: if tld_type not in DomainType.
        """
        key = self._validate_enum(item=tld_type, enum=TLDType)
        return self.random.choice(TLD[key])

    def subreddit(self, nsfw: bool = False,
                  full_url: bool = False) -> str:
        """Get a random subreddit from the list.

        :param nsfw: NSFW subreddit.
        :param full_url: Full URL address.
        :return: Subreddit or URL to subreddit.

        :Example:
            https://www.reddit.com/r/flask/
        """
        url = 'http://www.reddit.com'
        if not nsfw:
            if not full_url:
                return self.random.choice(SUBREDDITS)
            else:
                return url + self.random.choice(SUBREDDITS)

        nsfw_sr = self.random.choice(SUBREDDITS_NSFW)
        result = url + nsfw_sr if full_url else nsfw_sr
        return result

    def user_agent(self) -> str:
        """Get a random user agent.

        :return: User agent.

        :Example:
            Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:15.0)
            Gecko/20100101 Firefox/15.0.1
        """
        return self.random.choice(USER_AGENTS)

    def network_protocol(self, layer: Optional[Layer] = None) -> str:
        """Get a random network protocol form OSI model.

        :param layer: Enum object Layer.
        :return: Protocol name.

        :Example:
            AMQP
        """
        key = self._validate_enum(item=layer, enum=Layer)
        protocols = NETWORK_PROTOCOLS[key]
        return self.random.choice(protocols)

    def port(self, port_range: PortRange = PortRange.ALL) -> int:
        """Generate random port.

        :param port_range: Range enum object.
        :return: Port number.
        :raises NonEnumerableError: if port_range is not in PortRange.

        :Example:
            8080
        """
        if port_range and port_range in PortRange:
            return self.random.randint(*port_range.value)
        else:
            raise NonEnumerableError(PortRange)

    def category_of_website(self):
        """Get random category of torrent portal.

        :return: Category name.

        :Example:
            Video/TV shows
        """
        return self.random.choice(TORRENT_CATEGORIES)
